"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QImage(QPaintDevice):
    """
    https://doc.qt.io/qt-6/qimage.html

    **Detailed Description**

    Qt provides four classes for handling image data: QImage, **QPixmap** ,
    **QBitmap**  and **QPicture** . QImage is designed and optimized for I/O,
    and for direct pixel access and manipulation, while **QPixmap**  is designed
    and optimized for showing images on screen. **QBitmap**  is only a
    convenience class that inherits **QPixmap** , ensuring a depth of 1.
    Finally, the **QPicture**  class is a paint device that records and replays
    **QPainter**  commands.

    Because QImage is a **QPaintDevice**  subclass, **QPainter**  can be used to
    draw directly onto images. When using **QPainter**  on a QImage, the
    painting can be performed in another thread than the current GUI thread.

    The QImage class supports several image formats described by the **Format**
    enum. These include monochrome, 8-bit, 32-bit and alpha-blended images which
    are available in all versions of Qt 4.x.

    QImage provides a collection of functions that can be used to obtain a
    variety of information about the image. There are also several functions
    that enables transformation of the image.

    QImage objects can be passed around by value since the QImage class uses
    **implicit data sharing** . QImage objects can also be streamed and
    compared.

    **Note:** If you would like to load QImage objects in a static build of Qt,
    refer to the **Plugin HowTo** .

    **Warning:** Painting on a QImage with the format
    **QImage::Format_Indexed8**  is not supported.

    **Reading and Writing Image Files**

    QImage provides several ways of loading an image file: The file can be
    loaded when constructing the QImage object, or by using the **load** () or
    **loadFromData** () functions later on. QImage also provides the static
    **fromData** () function, constructing a QImage from the given data. When
    loading an image, the file name can either refer to an actual file on disk
    or to one of the application's embedded resources. See **The Qt Resource
    System**  overview for details on how to embed images and other resource
    files in the application's executable.

    Simply call the **save** () function to save a QImage object.

    The complete list of supported file formats are available through the
    **QImageReader::supportedImageFormats** () and
    **QImageWriter::supportedImageFormats** () functions. New file formats can
    be added as plugins. By default, Qt supports the following formats:

    FormatDescriptionQt's support
    BMPWindows BitmapRead/write
    GIFGraphic
    Interchange Format (optional)Read
    JPGJoint Photographic Experts
    GroupRead/write
    JPEGJoint Photographic Experts GroupRead/write
    PNGPortable Network GraphicsRead/write
    PBMPortable BitmapRead
    PGMPortable GraymapRead
    PPMPortable PixmapRead/write
    XBMX11
    BitmapRead/write
    XPMX11 PixmapRead/write

    **Image Information**

    QImage provides a collection of functions that can be used to obtain a
    variety of information about the image:

    Available Functions
    GeometryThe **size** (), **width** (), **height** (),
    **dotsPerMeterX** (), and **dotsPerMeterY** () functions provide information
    about the image size and aspect ratio.

    The **rect** () function returns the
    image's enclosing rectangle. The **valid** () function tells if a given pair
    of coordinates is within this rectangle. The **offset** () function returns
    the number of pixels by which the image is intended to be offset by when
    positioned relative to other images, which also can be manipulated using the
    **setOffset** () function.

    ColorsThe color of a pixel can be retrieved
    by passing its coordinates to the **pixel** () function. The **pixel** ()
    function returns the color as a **QRgb**  value independent of the image's
    format.

    In case of monochrome and 8-bit images, the **colorCount** () and
    **colorTable** () functions provide information about the color components
    used to store the image data: The **colorTable** () function returns the
    image's entire color table. To obtain a single entry, use the **pixelIndex**
    () function to retrieve the pixel index for a given pair of coordinates,
    then use the **color** () function to retrieve the color. Note that if you
    create an 8-bit image manually, you have to set a valid color table on the
    image as well.

    The **hasAlphaChannel** () function tells if the image's
    format respects the alpha channel, or not. The **allGray** () and
    **isGrayscale** () functions tell whether an image's colors are all shades
    of gray.

    See also the **Pixel Manipulation**  and **Image Transformations**
    sections.

    TextThe **text** () function returns the image text
    associated with the given text key. An image's text keys can be retrieved
    using the **textKeys** () function. Use the **setText** () function to alter
    an image's text.
    Low-level informationThe **depth** () function returns
    the depth of the image. The supported depths are 1 (monochrome), 8, 16, 24
    and 32 bits. The **bitPlaneCount** () function tells how many of those bits
    that are used. For more information see the **Image Formats**  section.

    The
    **format** (), **bytesPerLine** (), and **sizeInBytes** () functions provide
    low-level information about the data stored in the image.

    The **cacheKey**
    () function returns a number that uniquely identifies the contents of this
    QImage object.

    **Pixel Manipulation**

    The functions used to manipulate an image's pixels depend on the image
    format. The reason is that monochrome and 8-bit images are index-based and
    use a color lookup table, while 32-bit images store ARGB values directly.
    For more information on image formats, see the **Image Formats**  section.

    In case of a 32-bit image, the **setPixel** () function can be used to alter
    the color of the pixel at the given coordinates to any other color specified
    as an ARGB quadruplet. To make a suitable **QRgb**  value, use the **qRgb**
    () (adding a default alpha component to the given RGB values, i.e. creating
    an opaque color) or **qRgba** () function. For example:

    32-bit
    ![](images/qimage-32bit_scaled.png)



        **QImage**
    image(3, 3, **QImage** ::Format_RGB32);
        **QRgb**  value;

        value
    = **qRgb** (189, 149, 39); // 0xffbd9527
        image.setPixel(1, 1, value);
    value = **qRgb** (122, 163, 39); // 0xff7aa327
        image.setPixel(0, 1,
    value);
        image.setPixel(1, 0, value);

        value = **qRgb** (237,
    187, 51); // 0xffedba31
        image.setPixel(2, 1, value);

    In case of a 8-bit and monchrome images, the pixel value is only an index
    from the image's color table. So the **setPixel** () function can only be
    used to alter the color of the pixel at the given coordinates to a
    predefined color from the image's color table, i.e. it can only change the
    pixel's index value. To alter or add a color to an image's color table, use
    the **setColor** () function.

    An entry in the color table is an ARGB quadruplet encoded as an **QRgb**
    value. Use the **qRgb** () and **qRgba** () functions to make a suitable
    **QRgb**  value for use with the **setColor** () function. For example:

    8-bit
    ![](images/qimage-8bit_scaled.png)



        **QImage**
    image(3, 3, **QImage** ::Format_Indexed8);
        **QRgb**  value;
    value = **qRgb** (122, 163, 39); // 0xff7aa327
        image.setColor(0, value);
    value = **qRgb** (237, 187, 51); // 0xffedba31
        image.setColor(1, value);
    value = **qRgb** (189, 149, 39); // 0xffbd9527
        image.setColor(2, value);
    image.setPixel(0, 1, 0);
        image.setPixel(1, 0, 0);
        image.setPixel(1,
    1, 2);
        image.setPixel(2, 1, 1);

    For images with more than 8-bit per color-channel. The methods
    **setPixelColor** () and **pixelColor** () can be used to set and get with
    **QColor**  values.

    QImage also provide the **scanLine** () function which returns a pointer to
    the pixel data at the scanline with the given index, and the **bits** ()
    function which returns a pointer to the first pixel data (this is equivalent
    to `scanLine(0)`).

    **Image Formats**

    Each pixel stored in a QImage is represented by an integer. The size of the
    integer varies depending on the format. QImage supports several image
    formats described by the **Format**  enum.

    Monochrome images are stored using 1-bit indexes into a color table with at
    most two colors. There are two different types of monochrome images: big
    endian (MSB first) or little endian (LSB first) bit order.

    8-bit images are stored using 8-bit indexes into a color table, i.e. they
    have a single byte per pixel. The color table is a **QList** <**QRgb** >,
    and the **QRgb**  typedef is equivalent to an unsigned int containing an
    ARGB quadruplet on the format 0xAARRGGBB.

    32-bit images have no color table; instead, each pixel contains an **QRgb**
    value. There are three different types of 32-bit images storing RGB (i.e.
    0xffRRGGBB), ARGB and premultiplied ARGB values respectively. In the
    premultiplied format the red, green, and blue channels are multiplied by the
    alpha component divided by 255.

    An image's format can be retrieved using the **format** () function. Use the
    **convertToFormat** () functions to convert an image into another format.
    The **allGray** () and **isGrayscale** () functions tell whether a color
    image can safely be converted to a grayscale image.

    **Image Transformations**

    QImage supports a number of functions for creating a new image that is a
    transformed version of the original: The **createAlphaMask** () function
    builds and returns a 1-bpp mask from the alpha buffer in this image, and the
    **createHeuristicMask** () function creates and returns a 1-bpp heuristic
    mask for this image. The latter function works by selecting a color from one
    of the corners, then chipping away pixels of that color starting at all the
    edges.

    The **mirrored** () function returns a mirror of the image in the desired
    direction, the **scaled** () returns a copy of the image scaled to a
    rectangle of the desired measures, and the **rgbSwapped** () function
    constructs a BGR image from a RGB image.

    The **scaledToWidth** () and **scaledToHeight** () functions return scaled
    copies of the image.

    The **transformed** () function returns a copy of the image that is
    transformed with the given transformation matrix and transformation mode:
    Internally, the transformation matrix is adjusted to compensate for unwanted
    translation, i.e. **transformed** () returns the smallest image containing
    all transformed points of the original image. The static **trueMatrix** ()
    function returns the actual matrix used for transforming the image.

    There are also functions for changing attributes of an image in-place:

    FunctionDescription
    **setDotsPerMeterX** ()Defines the aspect ratio by
    setting the number of pixels that fit horizontally in a physical meter.
    **setDotsPerMeterY** ()Defines the aspect ratio by setting the number of
    pixels that fit vertically in a physical meter.
    **fill** ()Fills the
    entire image with the given pixel value.
    **invertPixels** ()Inverts all
    pixel values in the image using the given **InvertMode**  value.
    **setColorTable** ()Sets the color table used to translate color indexes.
    Only monochrome and 8-bit formats.
    **setColorCount** ()Resizes the color
    table. Only monochrome and 8-bit formats.

    **See also** **QImageReader** , **QImageWriter** , **QPixmap** ,
    **QSvgRenderer** , **Image Composition Example** , **Image Viewer Example**
    , **Scribble Example** , and **Pixelator Example** .
    """

    class Format(enum.Enum):
        Format_Invalid: QImage = ...
        Format_Mono: QImage = ...
        Format_MonoLSB: QImage = ...
        Format_Indexed8: QImage = ...
        Format_RGB32: QImage = ...
        Format_ARGB32: QImage = ...
        Format_ARGB32_Premultiplied: QImage = ...
        Format_RGB16: QImage = ...
        Format_ARGB8565_Premultiplied: QImage = ...
        Format_RGB666: QImage = ...
        Format_ARGB6666_Premultiplied: QImage = ...
        Format_RGB555: QImage = ...
        Format_ARGB8555_Premultiplied: QImage = ...
        Format_RGB888: QImage = ...
        Format_RGB444: QImage = ...
        Format_ARGB4444_Premultiplied: QImage = ...
        Format_RGBX8888: QImage = ...
        Format_RGBA8888: QImage = ...
        Format_RGBA8888_Premultiplied: QImage = ...
        Format_BGR30: QImage = ...
        Format_A2BGR30_Premultiplied: QImage = ...
        Format_RGB30: QImage = ...
        Format_A2RGB30_Premultiplied: QImage = ...
        Format_Alpha8: QImage = ...
        Format_Grayscale8: QImage = ...
        Format_RGBX64: QImage = ...
        Format_RGBA64: QImage = ...
        Format_RGBA64_Premultiplied: QImage = ...
        Format_Grayscale16: QImage = ...
        Format_BGR888: QImage = ...
        Format_RGBX16FPx4: QImage = ...
        Format_RGBA16FPx4: QImage = ...
        Format_RGBA16FPx4_Premultiplied: QImage = ...
        Format_RGBX32FPx4: QImage = ...
        Format_RGBA32FPx4: QImage = ...
        Format_RGBA32FPx4_Premultiplied: QImage = ...

    class InvertMode(enum.Enum):
        InvertRgb: QImage = ...
        InvertRgba: QImage = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage

        **QImage::QImage()**

        Constructs a null image.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, size: QtCore.QSize, format: "QImage.Format") -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-1

        **QImage::QImage(const QSize & size , QImage::Format format )**

        Constructs an image with the given **size** and **format**.

        A **null**  image is returned if memory cannot be allocated.

        **Warning:** This will create a QImage with uninitialized data. Call
        **fill** () to fill the image with an appropriate pixel value before
        drawing onto it with **QPainter** .
        """
        ...

    @typing.overload
    def __init__(self, width: int, height: int, format: "QImage.Format") -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-2

        **QImage::QImage(int width , int height , QImage::Format format )**

        Constructs an image with the given **width** , **height** and
        **format**.

        A **null**  image will be returned if memory cannot be allocated.

        **Warning:** This will create a QImage with uninitialized data. Call
        **fill** () to fill the image with an appropriate pixel value before
        drawing onto it with **QPainter** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        data: bytes,
        width: int,
        height: int,
        format: "QImage.Format",
        cleanupFunction: typing.Optional[typing.Callable[..., None]] = ...,
        cleanupInfo: typing.Optional[typing.Any] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-3

        **QImage::QImage(uchar * data , int width , int height , QImage::Format
        format , QImageCleanupFunction cleanupFunction = nullptr, void *
        cleanupInfo = nullptr)**

        Constructs an image with the given **width** , **height** and **format**
        , that uses an existing memory buffer, **data**. The **width** and
        **height** must be specified in pixels, **data** must be 32-bit aligned,
        and each scanline of data in the image must also be 32-bit aligned.

        The buffer must remain valid throughout the life of the QImage and all
        copies that have not been modified or otherwise detached from the
        original buffer. The image does not delete the buffer at destruction.
        You can provide a function pointer **cleanupFunction** along with an
        extra pointer **cleanupInfo** that will be called when the last copy is
        destroyed.

        If **format** is an indexed color format, the image color table is
        initially empty and must be sufficiently expanded with **setColorCount**
        () or **setColorTable** () before the image is used.
        """
        ...

    @typing.overload
    def __init__(
        self,
        data: bytes,
        width: int,
        height: int,
        bytesPerLine: int,
        format: "QImage.Format",
        cleanupFunction: typing.Optional[typing.Callable[..., None]] = ...,
        cleanupInfo: typing.Optional[typing.Any] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-4

        **QImage::QImage(const uchar * data , int width , int height ,
        QImage::Format format , QImageCleanupFunction cleanupFunction = nullptr,
        void * cleanupInfo = nullptr)**

        Constructs an image with the given **width** , **height** and **format**
        , that uses an existing read-only memory buffer, **data**. The **width**
        and **height** must be specified in pixels, **data** must be 32-bit
        aligned, and each scanline of data in the image must also be 32-bit
        aligned.

        The buffer must remain valid throughout the life of the QImage and all
        copies that have not been modified or otherwise detached from the
        original buffer. The image does not delete the buffer at destruction.
        You can provide a function pointer **cleanupFunction** along with an
        extra pointer **cleanupInfo** that will be called when the last copy is
        destroyed.

        If **format** is an indexed color format, the image color table is
        initially empty and must be sufficiently expanded with **setColorCount**
        () or **setColorTable** () before the image is used.

        Unlike the similar QImage constructor that takes a non-const data
        buffer, this version will never alter the contents of the buffer. For
        example, calling **QImage::bits** () will return a deep copy of the
        image, rather than the buffer passed to the constructor. This allows for
        the efficiency of constructing a QImage from raw data, without the
        possibility of the raw data being changed.
        """
        ...

    @typing.overload
    def __init__(self, xpm: typing.List[str]) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-5

        **QImage::QImage(uchar * data , int width , int height , qsizetype
        bytesPerLine , QImage::Format format , QImageCleanupFunction
        cleanupFunction = nullptr, void * cleanupInfo = nullptr)**

        Constructs an image with the given **width** , **height** and **format**
        , that uses an existing memory buffer, **data**. The **width** and
        **height** must be specified in pixels. **bytesPerLine** specifies the
        number of bytes per line (stride).

        The buffer must remain valid throughout the life of the QImage and all
        copies that have not been modified or otherwise detached from the
        original buffer. The image does not delete the buffer at destruction.
        You can provide a function pointer **cleanupFunction** along with an
        extra pointer **cleanupInfo** that will be called when the last copy is
        destroyed.

        If **format** is an indexed color format, the image color table is
        initially empty and must be sufficiently expanded with **setColorCount**
        () or **setColorTable** () before the image is used.
        """
        ...

    @typing.overload
    def __init__(self, fileName: str, format: typing.Optional[str] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-6

        **QImage::QImage(const uchar * data , int width , int height , qsizetype
        bytesPerLine , QImage::Format format , QImageCleanupFunction
        cleanupFunction = nullptr, void * cleanupInfo = nullptr)**

        Constructs an image with the given **width** , **height** and **format**
        , that uses an existing memory buffer, **data**. The **width** and
        **height** must be specified in pixels. **bytesPerLine** specifies the
        number of bytes per line (stride).

        The buffer must remain valid throughout the life of the QImage and all
        copies that have not been modified or otherwise detached from the
        original buffer. The image does not delete the buffer at destruction.
        You can provide a function pointer **cleanupFunction** along with an
        extra pointer **cleanupInfo** that will be called when the last copy is
        destroyed.

        If **format** is an indexed color format, the image color table is
        initially empty and must be sufficiently expanded with **setColorCount**
        () or **setColorTable** () before the image is used.

        Unlike the similar QImage constructor that takes a non-const data
        buffer, this version will never alter the contents of the buffer. For
        example, calling **QImage::bits** () will return a deep copy of the
        image, rather than the buffer passed to the constructor. This allows for
        the efficiency of constructing a QImage from raw data, without the
        possibility of the raw data being changed.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QImage") -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-7

        **QImage::QImage(const char *const [] xpm )**

        Constructs an image from the given **xpm** image.

        Make sure that the image is a valid XPM image. Errors are silently
        ignored.

        Note that it's possible to squeeze the XPM variable a little bit by
        using an unusual declaration:

        static const char * const start_xpm[] = {
                "16 15 8 1",
        "a c #cec6bd",
                // etc.
            };

        The extra `const` makes the entire definition read-only, which is
        slightly more efficient (e.g., when the code is in a shared library) and
        able to be stored in ROM with the application.
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#QImage-8

        **QImage::QImage(const QString & fileName , const char * format =
        nullptr)**

        Constructs an image and tries to load the image from the file with the
        given **fileName**.

        The loader attempts to read the image using the specified **format**. If
        the **format** is not specified (which is the default), it is auto-
        detected based on the file's suffix and header. For details, see
        {**QImageReader::setAutoDetectImageFormat** ()}{**QImageReader** }.

        If the loading of the image failed, this object is a null image.

        The file name can either refer to an actual file on disk or to one of
        the application's embedded resources. See the **Resource System**
        overview for details on how to embed images and other resource files in
        the application's executable.

        **See also** **isNull** () and **Reading and Writing Image Files** .
        """
        ...

    def deviceIndependentSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qimage.html#deviceIndependentSize

        **QSizeF QImage::deviceIndependentSize() const**

        Returns the size of the pixmap in device independent pixels.

        This value should be used when using the pixmap size in user interface
        size calculations.

        The return value is equivalent to pixmap.**size** () /
        pixmap.**devicePixelRatio** (),
        """
        ...

    def applyColorTransform(self, transform: QColorTransform) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#applyColorTransform

        **[since 5.14] void QImage::applyColorTransform(const QColorTransform &
        transform )**

        Applies the color transformation **transform** to all pixels in the
        image.

        This function was introduced in Qt 5.14.
        """
        ...

    def convertToColorSpace(self, a0: QColorSpace) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#convertToColorSpace

        **[since 5.14] void QImage::convertToColorSpace(const QColorSpace &
        colorSpace )**

        Converts the image to **colorSpace**.

        If the image has no valid color space, the method does nothing.

        This function was introduced in Qt 5.14.

        **See also** **convertedToColorSpace** () and **setColorSpace** ().
        """
        ...

    def convertedToColorSpace(self, a0: QColorSpace) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#convertedToColorSpace

        **[since 5.14] QImage QImage::convertedToColorSpace(const QColorSpace &
        colorSpace ) const**

        Returns the image converted to **colorSpace**.

        If the image has no valid color space, a null **QImage**  is returned.

        This function was introduced in Qt 5.14.

        **See also** **convertToColorSpace** ().
        """
        ...

    def setColorSpace(self, a0: QColorSpace) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setColorSpace

        **[since 5.14] void QImage::setColorSpace(const QColorSpace & colorSpace
        )**

        Sets the image color space to **colorSpace** without performing any
        conversions on image data.

        This function was introduced in Qt 5.14.

        **See also** **colorSpace** ().
        """
        ...

    def colorSpace(self) -> QColorSpace:
        """
        https://doc.qt.io/qt-6/qimage.html#colorSpace

        **[since 5.14] QColorSpace QImage::colorSpace() const**

        Returns the color space of the image if a color space is defined.

        This function was introduced in Qt 5.14.

        **See also** **setColorSpace** ().
        """
        ...

    def convertTo(
        self, f: "QImage.Format", flags: QtCore.Qt.ImageConversionFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#convertTo

        **[since 5.13] void QImage::convertTo(QImage::Format format ,
        Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Converts the image to the given **format** in place, detaching if
        necessary.

        The specified image conversion **flags** control how the image data is
        handled during the conversion process.

        This function was introduced in Qt 5.13.

        **See also** **convertedTo** ().
        """
        ...

    def convertedTo(
        self, f: "QImage.Format", flags: QtCore.Qt.ImageConversionFlag = ...
    ) -> "QImage":
        ...

    def sizeInBytes(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#sizeInBytes

        **[since 5.10] qsizetype QImage::sizeInBytes() const**

        Returns the image data size in bytes.

        This function was introduced in Qt 5.10.

        **See also** **bytesPerLine** (), **bits** (), and **Image Information**
        .
        """
        ...

    def reinterpretAsFormat(self, f: "QImage.Format") -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#reinterpretAsFormat

        **[since 5.9] bool QImage::reinterpretAsFormat(QImage::Format format )**

        Changes the format of the image to **format** without changing the data.
        Only works between formats of the same depth.

        Returns `true` if successful.

        This function can be used to change images with alpha-channels to their
        corresponding opaque formats if the data is known to be opaque-only, or
        to change the format of a given image buffer before overwriting it with
        new data.

        **Warning:** The function does not check if the image data is valid in
        the new format and will still return `true` if the depths are
        compatible. Operations on an image with invalid data are undefined.

        **Warning:** If the image is not detached, this will cause the data to
        be copied.

        This function was introduced in Qt 5.9.

        **See also** **hasAlphaChannel** () and **convertToFormat** ().
        """
        ...

    @typing.overload
    def setPixelColor(
        self,
        x: int,
        y: int,
        c: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setPixelColor

        **[since 5.6] void QImage::setPixelColor(const QPoint & position , const
        QColor & color )**

        Sets the color at the given **position** to **color**.

        If **position** is not a valid coordinate pair in the image, or the
        image's format is either monochrome or paletted, the result is
        undefined.

        **Warning:** This function is expensive due to the call of the internal
        `detach()` function called within; if performance is a concern, we
        recommend the use of **scanLine** () or **bits** () to access pixel data
        directly.

        This function was introduced in Qt 5.6.

        **See also** **pixelColor** (), **pixel** (), **bits** (), **scanLine**
        (), and **Pixel Manipulation** .
        """
        ...

    @typing.overload
    def setPixelColor(
        self,
        pt: QtCore.QPoint,
        c: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setPixelColor-1

        **[since 5.6] void QImage::setPixelColor(int x , int y , const QColor &
        color )**

        This is an overloaded function.

        Sets the pixel color at ( **x** , **y** ) to **color**.

        This function was introduced in Qt 5.6.
        """
        ...

    @typing.overload
    def pixelColor(self, x: int, y: int) -> QColor:
        """
        https://doc.qt.io/qt-6/qimage.html#pixelColor

        **[since 5.6] QColor QImage::pixelColor(const QPoint & position )
        const**

        Returns the color of the pixel at the given **position** as a **QColor**
        .

        If the **position** is not valid, an invalid **QColor**  is returned.

        **Warning:** This function is expensive when used for massive pixel
        manipulations. Use **constBits** () or **constScanLine** () when many
        pixels needs to be read.

        This function was introduced in Qt 5.6.

        **See also** **setPixelColor** (), **setPixel** (), **valid** (),
        **constBits** (), **constScanLine** (), and **Pixel Manipulation** .
        """
        ...

    @typing.overload
    def pixelColor(self, pt: QtCore.QPoint) -> QColor:
        """
        https://doc.qt.io/qt-6/qimage.html#pixelColor-1

        **[since 5.6] QColor QImage::pixelColor(int x , int y ) const**

        This is an overloaded function.

        Returns the color of the pixel at coordinates ( **x** , **y** ) as a
        **QColor** .

        This function was introduced in Qt 5.6.
        """
        ...

    @staticmethod
    def toImageFormat(format: "QPixelFormat") -> "QImage.Format":
        """
        https://doc.qt.io/qt-6/qimage.html#toImageFormat

        **[static] QImage::Format QImage::toImageFormat(QPixelFormat format )**

        Converts **format** into a **QImage::Format**
        """
        ...

    @staticmethod
    def toPixelFormat(format: "QImage.Format") -> "QPixelFormat":
        """
        https://doc.qt.io/qt-6/qimage.html#toPixelFormat

        **[static] QPixelFormat QImage::toPixelFormat(QImage::Format format )**

        Converts **format** into a **QPixelFormat**
        """
        ...

    def pixelFormat(self) -> "QPixelFormat":
        """
        https://doc.qt.io/qt-6/qimage.html#pixelFormat

        **QPixelFormat QImage::pixelFormat() const**

        Returns the **QImage::Format**  as a **QPixelFormat**
        """
        ...

    def setDevicePixelRatio(self, scaleFactor: float) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setDevicePixelRatio

        **void QImage::setDevicePixelRatio(qreal scaleFactor )**

        Sets the device pixel ratio for the image. This is the ratio between
        image pixels and device-independent pixels.

        The default **scaleFactor** is 1.0. Setting it to something else has two
        effects:

        QPainters that are opened on the image will be scaled. For example,
        painting on a 200x200 image if with a ratio of 2.0 will result in
        effective (device-independent) painting bounds of 100x100.

        Code paths in Qt that calculate layout geometry based on the image size
        will take the ratio into account: **QSize**  layoutSize = image.**size**
        () / image.**devicePixelRatio** () The net effect of this is that the
        image is displayed as high-DPI image rather than a large image (see
        **Drawing High Resolution Versions of Pixmaps and Images** ).

        **See also** **devicePixelRatio** () and **deviceIndependentSize** ().
        """
        ...

    def devicePixelRatio(self) -> float:
        """
        https://doc.qt.io/qt-6/qimage.html#devicePixelRatio

        **qreal QImage::devicePixelRatio() const**

        Returns the device pixel ratio for the image. This is the ratio between
        **device pixels** and **device independent pixels**.

        Use this function when calculating layout geometry based on the image
        size: **QSize**  layoutSize = image.**size** () /
        image.devicePixelRatio()

        The default value is 1.0.

        **See also** **setDevicePixelRatio** () and **QImageReader** .
        """
        ...

    def swap(self, other: "QImage") -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#swap

        **void QImage::swap(QImage & other )**

        Swaps image **other** with this image. This operation is very fast and
        never fails.
        """
        ...

    def bitPlaneCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#bitPlaneCount

        **int QImage::bitPlaneCount() const**

        Returns the number of bit planes in the image.

        The number of bit planes is the number of bits of color and transparency
        information for each pixel. This is different from (i.e. smaller than)
        the depth when the image format contains unused bits.

        **See also** **depth** (), **format** (), and **Image Formats** .
        """
        ...

    def setColorCount(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setColorCount

        **void QImage::setColorCount(int colorCount )**

        Resizes the color table to contain **colorCount** entries.

        If the color table is expanded, all the extra colors will be set to
        transparent (i.e **qRgba** (0, 0, 0, 0)).

        When the image is used, the color table must be large enough to have
        entries for all the pixel/index values present in the image, otherwise
        the results are undefined.

        **See also** **colorCount** (), **colorTable** (), **setColor** (), and
        **Image Transformations** .
        """
        ...

    def colorCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#colorCount

        **int QImage::colorCount() const**

        Returns the size of the color table for the image.

        Notice that colorCount() returns 0 for 32-bpp images because these
        images do not use color tables, but instead encode pixel values as ARGB
        quadruplets.

        **See also** **setColorCount** () and **Image Information** .
        """
        ...

    def cacheKey(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#cacheKey

        **qint64 QImage::cacheKey() const**

        Returns a number that identifies the contents of this **QImage**
        object. Distinct **QImage**  objects can only have the same key if they
        refer to the same contents.

        The key will change when the image is altered.
        """
        ...

    @staticmethod
    def trueMatrix(a0: "QTransform", w: int, h: int) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qimage.html#trueMatrix

        **[static] QTransform QImage::trueMatrix(const QTransform & matrix , int
        width , int height )**

        Returns the actual matrix used for transforming an image with the given
        **width** , **height** and **matrix**.

        When transforming an image using the **transformed** () function, the
        transformation matrix is internally adjusted to compensate for unwanted
        translation, i.e. **transformed** () returns the smallest image
        containing all transformed points of the original image. This function
        returns the modified matrix, which maps points correctly from the
        original image into the new image.

        Unlike the other overload, this function creates transformation matrices
        that can be used to perform perspective transformations on images.

        **See also** **transformed** () and **Image Transformations** .
        """
        ...

    def transformed(
        self, matrix: "QTransform", mode: QtCore.Qt.TransformationMode = ...
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#transformed

        **QImage QImage::transformed(const QTransform & matrix ,
        Qt::TransformationMode mode = Qt::FastTransformation) const**

        Returns a copy of the image that is transformed using the given
        transformation **matrix** and transformation **mode**.

        The returned image will normally have the same {Image Formats}{format}
        as the original image. However, a complex transformation may result in
        an image where not all pixels are covered by the transformed pixels of
        the original image. In such cases, those background pixels will be
        assigned a transparent color value, and the transformed image will be
        given a format with an alpha channel, even if the original image did not
        have that.

        The transformation **matrix** is internally adjusted to compensate for
        unwanted translation; i.e. the image produced is the smallest image that
        contains all the transformed points of the original image. Use the
        **trueMatrix** () function to retrieve the actual matrix used for
        transforming an image.

        Unlike the other overload, this function can be used to perform
        perspective transformations on images.

        **See also** **trueMatrix** () and **Image Transformations** .
        """
        ...

    def createMaskFromColor(
        self, color: int, mode: QtCore.Qt.MaskMode = ...
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#createMaskFromColor

        **QImage QImage::createMaskFromColor(QRgb color , Qt::MaskMode mode =
        Qt::MaskInColor) const**

        Creates and returns a mask for this image based on the given **color**
        value. If the **mode** is MaskInColor (the default value), all pixels
        matching **color** will be opaque pixels in the mask. If **mode** is
        MaskOutColor, all pixels matching the given color will be transparent.

        **See also** **createAlphaMask** () and **createHeuristicMask** ().
        """
        ...

    def setText(self, key: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setText

        **void QImage::setText(const QString & key , const QString & text )**

        Sets the image text to the given **text** and associate it with the
        given **key**.

        If you just want to store a single text block (i.e., a "comment" or just
        a description), you can either pass an empty key, or use a generic key
        like "Description".

        The image text is embedded into the image data when you call **save** ()
        or **QImageWriter::write** ().

        Not all image formats support embedded text. You can find out if a
        specific image or format supports embedding text by using
        **QImageWriter::supportsOption** (). We give an example:

        **QImageWriter**  writer;
                writer.setFormat("png");
                if
        (writer.supportsOption(**QImageIOHandler** ::Description))
        **qDebug** () << "Png supports embedded text";

        You can use **QImageWriter::supportedImageFormats** () to find out which
        image formats are available to you.

        **See also** **text** () and **textKeys** ().
        """
        ...

    def text(self, key: str = ...) -> str:
        """
        https://doc.qt.io/qt-6/qimage.html#text

        **QString QImage::text(const QString & key = QString()) const**

        Returns the image text associated with the given **key**. If the
        specified **key** is an empty string, the whole image text is returned,
        with each key-text pair separated by a newline.

        **See also** **setText** () and **textKeys** ().
        """
        ...

    def textKeys(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qimage.html#textKeys

        **QStringList QImage::textKeys() const**

        Returns the text keys for this image.

        You can use these keys with **text** () to list the image text for a
        certain key.

        **See also** **text** ().
        """
        ...

    def setOffset(self, a0: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setOffset

        **void QImage::setOffset(const QPoint & offset )**

        Sets the number of pixels by which the image is intended to be offset by
        when positioning relative to other images, to **offset**.

        **See also** **offset** () and **Image Information** .
        """
        ...

    def offset(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qimage.html#offset

        **QPoint QImage::offset() const**

        Returns the number of pixels by which the image is intended to be offset
        by when positioning relative to other images.

        **See also** **setOffset** () and **Image Information** .
        """
        ...

    def setDotsPerMeterY(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setDotsPerMeterY

        **void QImage::setDotsPerMeterY(int y )**

        Sets the number of pixels that fit vertically in a physical meter, to
        **y**.

        Together with **dotsPerMeterX** (), this number defines the intended
        scale and aspect ratio of the image, and determines the scale at which
        **QPainter**  will draw graphics on the image. It does not change the
        scale or aspect ratio of the image when it is rendered on other paint
        devices.

        **See also** **dotsPerMeterY** () and **Image Information** .
        """
        ...

    def setDotsPerMeterX(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setDotsPerMeterX

        **void QImage::setDotsPerMeterX(int x )**

        Sets the number of pixels that fit horizontally in a physical meter, to
        **x**.

        Together with **dotsPerMeterY** (), this number defines the intended
        scale and aspect ratio of the image, and determines the scale at which
        **QPainter**  will draw graphics on the image. It does not change the
        scale or aspect ratio of the image when it is rendered on other paint
        devices.

        **See also** **dotsPerMeterX** () and **Image Information** .
        """
        ...

    def dotsPerMeterY(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#dotsPerMeterY

        **int QImage::dotsPerMeterY() const**

        Returns the number of pixels that fit vertically in a physical meter.
        Together with **dotsPerMeterX** (), this number defines the intended
        scale and aspect ratio of the image.

        **See also** **setDotsPerMeterY** () and **Image Information** .
        """
        ...

    def dotsPerMeterX(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#dotsPerMeterX

        **int QImage::dotsPerMeterX() const**

        Returns the number of pixels that fit horizontally in a physical meter.
        Together with **dotsPerMeterY** (), this number defines the intended
        scale and aspect ratio of the image.

        **See also** **setDotsPerMeterX** () and **Image Information** .
        """
        ...

    def paintEngine(self) -> "QPaintEngine":
        ...

    @typing.overload
    @staticmethod
    def fromData(data: bytes, format: typing.Optional[str] = ...) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#fromData

        **[static, since 6.2] QImage QImage::fromData(QByteArrayView data ,
        const char * format = nullptr)**

        Constructs an image from the given **QByteArrayView**  **data**. The
        loader attempts to read the image using the specified **format**. If
        **format** is not specified (which is the default), the loader probes
        the data for a header to guess the file format.

        If **format** is specified, it must be one of the values returned by
        **QImageReader::supportedImageFormats** ().

        If the loading of the image fails, the image returned will be a null
        image.

        This function was introduced in Qt 6.2.

        **See also** **load** (), **save** (), and **Reading and Writing Image
        Files** .
        """
        ...

    @typing.overload
    @staticmethod
    def fromData(
        data: QtCore.QByteArray, format: typing.Optional[str] = ...
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#fromData-1

        **[static] QImage QImage::fromData(const uchar * data , int size , const
        char * format = nullptr)**

        This is an overloaded function.

        Constructs a **QImage**  from the first **size** bytes of the given
        binary **data**.
        """
        ...

    @typing.overload
    def save(
        self, fileName: str, format: typing.Optional[str] = ..., quality: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#save

        **bool QImage::save(const QString & fileName , const char * format =
        nullptr, int quality = -1) const**

        Saves the image to the file with the given **fileName** , using the
        given image file **format** and **quality** factor. If **format** is
        `nullptr`, **QImage**  will attempt to guess the format by looking at
        **fileName** 's suffix.

        The **quality** factor must be in the range 0 to 100 or -1. Specify 0 to
        obtain small compressed files, 100 for large uncompressed files, and -1
        (the default) to use the default settings.

        Returns `true` if the image was successfully saved; otherwise returns
        `false`.

        **See also** **Reading and Writing Image Files** .
        """
        ...

    @typing.overload
    def save(
        self,
        device: QtCore.QIODevice,
        format: typing.Optional[str] = ...,
        quality: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#save-1

        **bool QImage::save(QIODevice * device , const char * format = nullptr,
        int quality = -1) const**

        This is an overloaded function.

        This function writes a **QImage**  to the given **device**.

        This can, for example, be used to save an image directly into a
        **QByteArray** :

        **QImage**  image;
            **QByteArray**  ba;
            **QBuffer**  buffer(&ba);
        buffer.open(**QIODevice** ::WriteOnly);
            image.save(&buffer, "PNG");
        // writes image into ba in PNG format
        """
        ...

    @typing.overload
    def loadFromData(self, data: bytes, format: typing.Optional[str] = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#loadFromData

        **[since 6.2] bool QImage::loadFromData(QByteArrayView data , const char
        * format = nullptr)**

        Loads an image from the given **QByteArrayView**  **data**. Returns
        `true` if the image was successfully loaded; otherwise invalidates the
        image and returns `false`.

        The loader attempts to read the image using the specified **format** ,
        e.g., PNG or JPG. If **format** is not specified (which is the default),
        the loader probes the file for a header to guess the file format.

        This function was introduced in Qt 6.2.

        **See also** **Reading and Writing Image Files** .
        """
        ...

    @typing.overload
    def loadFromData(
        self, data: QtCore.QByteArray, format: typing.Optional[str] = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#loadFromData-1

        **bool QImage::loadFromData(const uchar * data , int len , const char *
        format = nullptr)**

        This is an overloaded function.

        Loads an image from the first **len** bytes of the given binary
        **data**.
        """
        ...

    @typing.overload
    def load(self, device: QtCore.QIODevice, format: str) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#load

        **bool QImage::load(const QString & fileName , const char * format =
        nullptr)**

        Loads an image from the file with the given **fileName**. Returns `true`
        if the image was successfully loaded; otherwise invalidates the image
        and returns `false`.

        The loader attempts to read the image using the specified **format** ,
        e.g., PNG or JPG. If **format** is not specified (which is the default),
        it is auto-detected based on the file's suffix and header. For details,
        see **QImageReader::setAutoDetectImageFormat** ().

        The file name can either refer to an actual file on disk or to one of
        the application's embedded resources. See the **Resource System**
        overview for details on how to embed images and other resource files in
        the application's executable.

        **See also** **Reading and Writing Image Files** .
        """
        ...

    @typing.overload
    def load(self, fileName: str, format: typing.Optional[str] = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#load-1

        **bool QImage::load(QIODevice * device , const char * format )**

        This is an overloaded function.

        This function reads a **QImage**  from the given **device**. This can,
        for example, be used to load an image directly into a **QByteArray** .
        """
        ...

    def invertPixels(self, mode: "QImage.InvertMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#invertPixels

        **void QImage::invertPixels(QImage::InvertMode mode = InvertRgb)**

        Inverts all pixel values in the image.

        The given invert **mode** only have a meaning when the image's depth is
        32. The default **mode** is **InvertRgb** , which leaves the alpha
        channel unchanged. If the **mode** is **InvertRgba** , the alpha bits
        are also inverted.

        Inverting an 8-bit image means to replace all pixels using color index
        **i** with a pixel using color index 255 minus **i**. The same is the
        case for a 1-bit image. Note that the color table is **not** changed.

        If the image has a premultiplied alpha channel, the image is first
        converted to an unpremultiplied image format to be inverted and then
        converted back.

        **See also** **Image Transformations** .
        """
        ...

    def rgbSwap(self) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#rgbSwap

        **[since 6.0] void QImage::rgbSwap()**

        Swaps the values of the red and blue components of all pixels,
        effectively converting an RGB image to an BGR image.

        This function was introduced in Qt 6.0.

        **See also** **rgbSwapped** () and **Image Transformations** .
        """
        ...

    def rgbSwapped(self) -> "QImage":
        ...

    def mirror(self, horizontal: bool = ..., vertical: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#mirror

        **[since 6.0] void QImage::mirror(bool horizontal = false, bool vertical
        = true)**

        Mirrors of the image in the horizontal and/or the vertical direction
        depending on whether **horizontal** and **vertical** are set to true or
        false.

        This function was introduced in Qt 6.0.

        **See also** **mirrored** () and **Image Transformations** .
        """
        ...

    def mirrored(self, horizontal: bool = ..., vertical: bool = ...) -> "QImage":
        ...

    def scaledToHeight(
        self, height: int, mode: QtCore.Qt.TransformationMode = ...
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#scaledToHeight

        **QImage QImage::scaledToHeight(int height , Qt::TransformationMode mode
        = Qt::FastTransformation) const**

        Returns a scaled copy of the image. The returned image is scaled to the
        given **height** using the specified transformation **mode**.

        This function automatically calculates the width of the image so that
        the ratio of the image is preserved.

        If the given **height** is 0 or negative, a null image is returned.

        **See also** **Image Transformations** .
        """
        ...

    def scaledToWidth(
        self, width: int, mode: QtCore.Qt.TransformationMode = ...
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#scaledToWidth

        **QImage QImage::scaledToWidth(int width , Qt::TransformationMode mode =
        Qt::FastTransformation) const**

        Returns a scaled copy of the image. The returned image is scaled to the
        given **width** using the specified transformation **mode**.

        This function automatically calculates the height of the image so that
        its aspect ratio is preserved.

        If the given **width** is 0 or negative, a null image is returned.

        **See also** **Image Transformations** .
        """
        ...

    @typing.overload
    def scaled(
        self,
        width: int,
        height: int,
        aspectRatioMode: QtCore.Qt.AspectRatioMode = ...,
        transformMode: QtCore.Qt.TransformationMode = ...,
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#scaled

        **QImage QImage::scaled(const QSize & size , Qt::AspectRatioMode
        aspectRatioMode = Qt::IgnoreAspectRatio, Qt::TransformationMode
        transformMode = Qt::FastTransformation) const**

        Returns a copy of the image scaled to a rectangle defined by the given
        **size** according to the given **aspectRatioMode** and
        **transformMode**.

        ![](images/qimage-scaling.png)

        * If **aspectRatioMode** is **Qt::IgnoreAspectRatio** , the image is
        scaled to **size**.
          * If **aspectRatioMode** is
        **Qt::KeepAspectRatio** , the image is scaled to a rectangle as large as
        possible inside **size** , preserving the aspect ratio.
          * If
        **aspectRatioMode** is **Qt::KeepAspectRatioByExpanding** , the image is
        scaled to a rectangle as small as possible outside **size** , preserving
        the aspect ratio.

        If the given **size** is empty, this function returns a null image.

        **See also** **isNull** () and **Image Transformations** .
        """
        ...

    @typing.overload
    def scaled(
        self,
        size: QtCore.QSize,
        aspectRatioMode: QtCore.Qt.AspectRatioMode = ...,
        transformMode: QtCore.Qt.TransformationMode = ...,
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#scaled-1

        **QImage QImage::scaled(int width , int height , Qt::AspectRatioMode
        aspectRatioMode = Qt::IgnoreAspectRatio, Qt::TransformationMode
        transformMode = Qt::FastTransformation) const**

        This is an overloaded function.

        Returns a copy of the image scaled to a rectangle with the given
        **width** and **height** according to the given **aspectRatioMode** and
        **transformMode**.

        If either the **width** or the **height** is zero or negative, this
        function returns a null image.
        """
        ...

    def createHeuristicMask(self, clipTight: bool = ...) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#createHeuristicMask

        **QImage QImage::createHeuristicMask(bool clipTight = true) const**

        Creates and returns a 1-bpp heuristic mask for this image.

        The function works by selecting a color from one of the corners, then
        chipping away pixels of that color starting at all the edges. The four
        corners vote for which color is to be masked away. In case of a draw
        (this generally means that this function is not applicable to the
        image), the result is arbitrary.

        The returned image has little-endian bit order (i.e. the image's format
        is **QImage::Format_MonoLSB** ), which you can convert to big-endian
        (**QImage::Format_Mono** ) using the **convertToFormat** () function.

        If **clipTight** is true (the default) the mask is just large enough to
        cover the pixels; otherwise, the mask is larger than the data pixels.

        Note that this function disregards the alpha buffer.

        **See also** **createAlphaMask** () and **Image Transformations** .
        """
        ...

    def createAlphaMask(self, flags: QtCore.Qt.ImageConversionFlag = ...) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#createAlphaMask

        **QImage QImage::createAlphaMask(Qt::ImageConversionFlags flags =
        Qt::AutoColor) const**

        Builds and returns a 1-bpp mask from the alpha buffer in this image.
        Returns a null image if the image's format is **QImage::Format_RGB32** .

        The **flags** argument is a bitwise-OR of the
        **Qt::ImageConversionFlags** , and controls the conversion process.
        Passing 0 for flags sets all the default options.

        The returned image has little-endian bit order (i.e. the image's format
        is **QImage::Format_MonoLSB** ), which you can convert to big-endian
        (**QImage::Format_Mono** ) using the **convertToFormat** () function.

        **See also** **createHeuristicMask** () and **Image Transformations** .
        """
        ...

    def setAlphaChannel(self, alphaChannel: "QImage") -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setAlphaChannel

        **void QImage::setAlphaChannel(const QImage & alphaChannel )**

        Sets the alpha channel of this image to the given **alphaChannel**.

        If **alphaChannel** is an 8 bit alpha image, the alpha values are used
        directly. Otherwise, **alphaChannel** is converted to 8 bit grayscale
        and the intensity of the pixel values is used.

        If the image already has an alpha channel, the existing alpha channel is
        multiplied with the new one. If the image doesn't have an alpha channel
        it will be converted to a format that does.

        The operation is similar to painting **alphaChannel** as an alpha image
        over this image using `QPainter::CompositionMode_DestinationIn`.

        **See also** **hasAlphaChannel** (), **Image Transformations** , and
        **Image Formats** .
        """
        ...

    def hasAlphaChannel(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#hasAlphaChannel

        **bool QImage::hasAlphaChannel() const**

        Returns `true` if the image has a format that respects the alpha
        channel, otherwise returns `false`.

        **See also** **Image Information** .
        """
        ...

    @typing.overload
    def fill(self, pixel: int) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#fill

        **void QImage::fill(uint pixelValue )**

        Fills the entire image with the given **pixelValue**.

        If the depth of this image is 1, only the lowest bit is used. If you say
        fill(0), fill(2), etc., the image is filled with 0s. If you say fill(1),
        fill(3), etc., the image is filled with 1s. If the depth is 8, the
        lowest 8 bits are used and if the depth is 16 the lowest 16 bits are
        used.

        If the image depth is higher than 32bit the result is undefined.

        **Note:** There are no corresponding value getter, though
        **QImage::pixelIndex** () will return the same value for indexed
        formats, and **QImage::pixel** () for RGB32, ARGB32, and ARGB32PM
        formats.

        **See also** **depth** () and **Image Transformations** .
        """
        ...

    @typing.overload
    def fill(self, color: QtCore.Qt.GlobalColor) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#fill-1

        **void QImage::fill(const QColor & color )**

        This is an overloaded function.

        Fills the entire image with the given **color**.

        If the depth of the image is 1, the image will be filled with 1 if
        **color** equals **Qt::color1** ; it will otherwise be filled with 0.

        If the depth of the image is 8, the image will be filled with the index
        corresponding the **color** in the color table if present; it will
        otherwise be filled with 0.
        """
        ...

    @typing.overload
    def fill(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#fill-2

        **void QImage::fill(Qt::GlobalColor color )**

        This is an overloaded function.

        Fills the image with the given **color** , described as a standard
        global color.
        """
        ...

    def setColorTable(self, colors: typing.Iterable[int]) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setColorTable

        **void QImage::setColorTable(const QList<QRgb> & colors )**

        Sets the color table used to translate color indexes to **QRgb**
        values, to the specified **colors**.

        When the image is used, the color table must be large enough to have
        entries for all the pixel/index values present in the image, otherwise
        the results are undefined.

        **See also** **colorTable** (), **setColor** (), and **Image
        Transformations** .
        """
        ...

    def colorTable(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qimage.html#colorTable

        **QList<QRgb> QImage::colorTable() const**

        Returns a list of the colors contained in the image's color table, or an
        empty list if the image does not have a color table

        **See also** **setColorTable** (), **colorCount** (), and **color** ().
        """
        ...

    @typing.overload
    def setPixel(self, pt: QtCore.QPoint, index_or_rgb: int) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setPixel

        **void QImage::setPixel(const QPoint & position , uint index_or_rgb )**

        Sets the pixel index or color at the given **position** to
        **index_or_rgb**.

        If the image's format is either monochrome or paletted, the given
        **index_or_rgb** value must be an index in the image's color table,
        otherwise the parameter must be a **QRgb**  value.

        If **position** is not a valid coordinate pair in the image, or if
        **index_or_rgb** >= **colorCount** () in the case of monochrome and
        paletted images, the result is undefined.

        **Warning:** This function is expensive due to the call of the internal
        `detach()` function called within; if performance is a concern, we
        recommend the use of **scanLine** () or **bits** () to access pixel data
        directly.

        **See also** **pixel** () and **Pixel Manipulation** .
        """
        ...

    @typing.overload
    def setPixel(self, x: int, y: int, index_or_rgb: int) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setPixel-1

        **void QImage::setPixel(int x , int y , uint index_or_rgb )**

        This is an overloaded function.

        Sets the pixel index or color at ( **x** , **y** ) to **index_or_rgb**.
        """
        ...

    @typing.overload
    def pixel(self, pt: QtCore.QPoint) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#pixel

        **QRgb QImage::pixel(const QPoint & position ) const**

        Returns the color of the pixel at the given **position**.

        If the **position** is not valid, the results are undefined.

        **Warning:** This function is expensive when used for massive pixel
        manipulations. Use **constBits** () or **constScanLine** () when many
        pixels needs to be read.

        **See also** **setPixel** (), **valid** (), **constBits** (),
        **constScanLine** (), and **Pixel Manipulation** .
        """
        ...

    @typing.overload
    def pixel(self, x: int, y: int) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#pixel-1

        **QRgb QImage::pixel(int x , int y ) const**

        This is an overloaded function.

        Returns the color of the pixel at coordinates ( **x** , **y** ).
        """
        ...

    @typing.overload
    def pixelIndex(self, pt: QtCore.QPoint) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#pixelIndex

        **int QImage::pixelIndex(const QPoint & position ) const**

        Returns the pixel index at the given **position**.

        If **position** is not valid, or if the image is not a paletted image
        (**depth** () > 8), the results are undefined.

        **See also** **valid** (), **depth** (), and **Pixel Manipulation** .
        """
        ...

    @typing.overload
    def pixelIndex(self, x: int, y: int) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#pixelIndex-1

        **int QImage::pixelIndex(int x , int y ) const**

        This is an overloaded function.

        Returns the pixel index at ( **x** , **y** ).
        """
        ...

    @typing.overload
    def valid(self, pt: QtCore.QPoint) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#valid

        **bool QImage::valid(const QPoint & pos ) const**

        Returns `true` if **pos** is a valid coordinate pair within the image;
        otherwise returns `false`.

        **See also** **rect** () and **QRect::contains** ().
        """
        ...

    @typing.overload
    def valid(self, x: int, y: int) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#valid-1

        **bool QImage::valid(int x , int y ) const**

        This is an overloaded function.

        Returns `true` if **QPoint** ( **x** , **y** ) is a valid coordinate
        pair within the image; otherwise returns `false`.
        """
        ...

    def bytesPerLine(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#bytesPerLine

        **qsizetype QImage::bytesPerLine() const**

        Returns the number of bytes per image scanline.

        This is equivalent to **sizeInBytes** () / **height** () if **height**
        () is non-zero.

        **See also** **scanLine** ().
        """
        ...

    def constScanLine(self, a0: int) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qimage.html#constScanLine

        **const uchar *QImage::constScanLine(int i ) const**

        Returns a pointer to the pixel data at the scanline with index **i**.
        The first scanline is at index 0.

        The scanline data is as minimum 32-bit aligned. For 64-bit formats it
        follows the native alignment of 64-bit integers (64-bit for most
        platforms, but notably 32-bit on i386).

        Note that **QImage**  uses **implicit data sharing** , but this function
        does **not** perform a deep copy of the shared pixel data, because the
        returned data is const.

        **See also** **scanLine** () and **constBits** ().
        """
        ...

    def scanLine(self, a0: int) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qimage.html#scanLine

        **uchar *QImage::scanLine(int i )**

        Returns a pointer to the pixel data at the scanline with index **i**.
        The first scanline is at index 0.

        The scanline data is as minimum 32-bit aligned. For 64-bit formats it
        follows the native alignment of 64-bit integers (64-bit for most
        platforms, but notably 32-bit on i386).

        For example, to remove the green component of each pixel in an image:

        for (int y = 0; y < image.height(); ++y) {
                **QRgb**  *line =
        reinterpret_cast<**QRgb** \\*>(image.scanLine(y));
                for (int x =
        0; x < image.width(); ++x) {
                    **QRgb**  &rgb = line[x];
        rgb = **qRgba** (qRed(rgb), qGreen(0), qBlue(rgb), qAlpha(rgb));
        }
            }

        **Warning:** If you are accessing 32-bpp image data, cast the returned
        pointer to `QRgb*` (**QRgb**  has a 32-bit size) and use it to
        read/write the pixel value. You cannot use the `uchar*` pointer
        directly, because the pixel format depends on the byte order on the
        underlying platform. Use qRed(), qGreen(), qBlue(), and qAlpha() to
        access the pixels.

        **See also** **bytesPerLine** (), **bits** (), **Pixel Manipulation** ,
        and **constScanLine** ().
        """
        ...

    def constBits(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qimage.html#constBits

        **const uchar *QImage::constBits() const**

        Returns a pointer to the first pixel data.

        Note that **QImage**  uses **implicit data sharing** , but this function
        does **not** perform a deep copy of the shared pixel data, because the
        returned data is const.

        **See also** **bits** () and **constScanLine** ().
        """
        ...

    def bits(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qimage.html#bits

        **uchar *QImage::bits()**

        Returns a pointer to the first pixel data. This is equivalent to
        **scanLine** (0).

        Note that **QImage**  uses **implicit data sharing** . This function
        performs a deep copy of the shared pixel data, thus ensuring that this
        **QImage**  is the only one using the current return value.

        **See also** **scanLine** (), **sizeInBytes** (), and **constBits** ().
        """
        ...

    def isGrayscale(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#isGrayscale

        **bool QImage::isGrayscale() const**

        For 32-bit images, this function is equivalent to **allGray** ().

        For color indexed images, this function returns `true` if color(i) is
        **QRgb** (i, i, i) for all indexes of the color table; otherwise returns
        `false`.

        **See also** **allGray** () and **Image Formats** .
        """
        ...

    def allGray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#allGray

        **bool QImage::allGray() const**

        Returns `true` if all the colors in the image are shades of gray (i.e.
        their red, green and blue components are equal); otherwise false.

        Note that this function is slow for images without color table.

        **See also** **isGrayscale** ().
        """
        ...

    def setColor(self, i: int, c: int) -> None:
        """
        https://doc.qt.io/qt-6/qimage.html#setColor

        **void QImage::setColor(int index , QRgb colorValue )**

        Sets the color at the given **index** in the color table, to the given
        to **colorValue**. The color value is an ARGB quadruplet.

        If **index** is outside the current size of the color table, it is
        expanded with **setColorCount** ().

        **See also** **color** (), **colorCount** (), **setColorTable** (), and
        **Pixel Manipulation** .
        """
        ...

    def color(self, i: int) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#color

        **QRgb QImage::color(int i ) const**

        Returns the color in the color table at index **i**. The first color is
        at index 0.

        The colors in an image's color table are specified as ARGB quadruplets
        (**QRgb** ). Use the qAlpha(), qRed(), qGreen(), and qBlue() functions
        to get the color value components.

        **See also** **setColor** (), **pixelIndex** (), and **Pixel
        Manipulation** .
        """
        ...

    def depth(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#depth

        **int QImage::depth() const**

        Returns the depth of the image.

        The image depth is the number of bits used to store a single pixel, also
        called bits per pixel (bpp).

        The supported depths are 1, 8, 16, 24, 32 and 64.

        **See also** **bitPlaneCount** (), **convertToFormat** (), **Image
        Formats** , and **Image Information** .
        """
        ...

    def rect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qimage.html#rect

        **QRect QImage::rect() const**

        Returns the enclosing rectangle (0, 0, **width** (), **height** ()) of
        the image.

        **See also** **Image Information** .
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qimage.html#size

        **QSize QImage::size() const**

        Returns the size of the image, i.e. its **width** () and **height** ().

        **See also** **Image Information**  and **deviceIndependentSize** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#height

        **int QImage::height() const**

        Returns the height of the image.

        **See also** **Image Information** .
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qimage.html#width

        **int QImage::width() const**

        Returns the width of the image.

        **See also** **Image Information** .
        """
        ...

    @typing.overload
    def convertToFormat(
        self, f: "QImage.Format", flags: QtCore.Qt.ImageConversionFlag = ...
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#convertToFormat-2

        **QImage QImage::convertToFormat(QImage::Format format , const
        QList<QRgb> & colorTable , Qt::ImageConversionFlags flags =
        Qt::AutoColor) const**

        This is an overloaded function.

        Returns a copy of the image converted to the given **format** , using
        the specified **colorTable**.

        Conversion from RGB formats to indexed formats is a slow operation and
        will use a straightforward nearest color approach, with no dithering.
        """
        ...

    @typing.overload
    def convertToFormat(
        self,
        f: "QImage.Format",
        colorTable: typing.Iterable[int],
        flags: QtCore.Qt.ImageConversionFlag = ...,
    ) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#convertToFormat-2

        **QImage QImage::convertToFormat(QImage::Format format , const
        QList<QRgb> & colorTable , Qt::ImageConversionFlags flags =
        Qt::AutoColor) const**

        This is an overloaded function.

        Returns a copy of the image converted to the given **format** , using
        the specified **colorTable**.

        Conversion from RGB formats to indexed formats is a slow operation and
        will use a straightforward nearest color approach, with no dithering.
        """
        ...

    def format(self) -> "QImage.Format":
        """
        https://doc.qt.io/qt-6/qimage.html#format

        **QImage::Format QImage::format() const**

        Returns the format of the image.

        **See also** **Image Formats** .
        """
        ...

    @typing.overload
    def copy(self, rect: QtCore.QRect = ...) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#copy

        **QImage QImage::copy(const QRect & rectangle = QRect()) const**

        Returns a sub-area of the image as a new image.

        The returned image is copied from the position ( **rectangle**.x(),
        **rectangle**.y()) in this image, and will always have the size of the
        given **rectangle**.

        In areas beyond this image, pixels are set to 0. For 32-bit RGB images,
        this means black; for 32-bit ARGB images, this means transparent black;
        for 8-bit images, this means the color with index 0 in the color table
        which can be anything; for 1-bit images, this means **Qt::color0** .

        If the given **rectangle** is a null rectangle the entire image is
        copied.

        **See also** **QImage** ().
        """
        ...

    @typing.overload
    def copy(self, x: int, y: int, w: int, h: int) -> "QImage":
        """
        https://doc.qt.io/qt-6/qimage.html#copy-1

        **QImage QImage::copy(int x , int y , int width , int height ) const**

        This is an overloaded function.

        The returned image is copied from the position ( **x** , **y** ) in this
        image, and will always have the given **width** and **height**. In areas
        beyond this image, pixels are set to 0.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimage.html#isNull

        **bool QImage::isNull() const**

        Returns `true` if it is a null image, otherwise returns `false`.

        A null image has all parameters set to zero and no allocated data.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QParallelAnimationGroup(QAnimationGroup):
    """
    https://doc.qt.io/qt-6/qparallelanimationgroup.html

    **Detailed Description**

    QParallelAnimationGroup--a **container for animations** \\--starts all its
    animations when it is **started**  itself, i.e., runs all animations in
    parallel. The animation group finishes when the longest lasting animation
    has finished.

    You can treat QParallelAnimationGroup as any other **QAbstractAnimation** ,
    e.g., pause, resume, or add it to other animation groups.

    **QParallelAnimationGroup**  *group = new **QParallelAnimationGroup** ;
    group->addAnimation(anim1);
            group->addAnimation(anim2);
    group->start();

    In this example, `anim1` and `anim2` are two **QPropertyAnimation** s that
    have already been set up.

    **See also** **QAnimationGroup** , **QPropertyAnimation** , and **The
    Animation Framework** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qparallelanimationgroup.html#QParallelAnimationGr
        oup

        **QParallelAnimationGroup::QParallelAnimationGroup(QObject * parent =
        nullptr)**

        Constructs a QParallelAnimationGroup. **parent** is passed to
        **QObject** 's constructor.
        """
        ...

    def updateDirection(self, direction: QAbstractAnimation.Direction) -> None:
        """
        https://doc.qt.io/qt-6/qparallelanimationgroup.html#updateDirection

        **[override virtual protected] void
        QParallelAnimationGroup::updateDirection(QAbstractAnimation::Direction
        direction )**

        Reimplements: **QAbstractAnimation::updateDirection**
        (QAbstractAnimation::Direction direction).
        """
        ...

    def updateState(
        self, newState: QAbstractAnimation.State, oldState: QAbstractAnimation.State
    ) -> None:
        """
        https://doc.qt.io/qt-6/qparallelanimationgroup.html#updateState

        **[override virtual protected] void
        QParallelAnimationGroup::updateState(QAbstractAnimation::State newState
        , QAbstractAnimation::State oldState )**

        Reimplements: **QAbstractAnimation::updateState**
        (QAbstractAnimation::State newState, QAbstractAnimation::State
        oldState).
        """
        ...

    def updateCurrentTime(self, currentTime: int) -> None:
        """
        https://doc.qt.io/qt-6/qparallelanimationgroup.html#updateCurrentTime

        **[override virtual protected] void
        QParallelAnimationGroup::updateCurrentTime(int currentTime )**

        Reimplements: **QAbstractAnimation::updateCurrentTime** (int
        currentTime).
        """
        ...

    def event(self, event: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qparallelanimationgroup.html#event

        **[override virtual protected] bool
        QParallelAnimationGroup::event(QEvent * event )**

        Reimplements: **QAnimationGroup::event** (QEvent *event).
        """
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qparallelanimationgroup.html#duration

        **[override virtual] int QParallelAnimationGroup::duration() const**

        Reimplements: **QAbstractAnimation::duration() const** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtGui import *
import enum


class QTextLength(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextlength.html

    **Detailed Description**

    When we specify a value for the length of an element in a text document, we
    often need to provide some other information so that the length is used in
    the way we expect. For example, when we specify a table width, the value can
    represent a fixed number of pixels, or it can be a percentage value. This
    information changes both the meaning of the value and the way it is used.

    Generally, this class is used to specify table widths. These can be
    specified either as a fixed amount of pixels, as a percentage of the
    containing frame's width, or by a variable width that allows it to take up
    just the space it requires.

    **See also** **QTextTable** .
    """

    class Type(enum.Enum):
        VariableLength: QTextLength = ...
        FixedLength: QTextLength = ...
        PercentageLength: QTextLength = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextlength.html#QTextLength

        **QTextLength::QTextLength()**

        Constructs a new length object which represents a variable size.
        """
        ...

    @typing.overload
    def __init__(self, atype: "QTextLength.Type", avalue: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextlength.html#QTextLength-1

        **QTextLength::QTextLength(QTextLength::Type type , qreal value )**

        Constructs a new length object of the given **type** and **value**.
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qtextlength.html#QTextLength

        **QTextLength::QTextLength()**

        Constructs a new length object which represents a variable size.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextLength") -> None:
        """
        https://doc.qt.io/qt-6/qtextlength.html#QTextLength

        **QTextLength::QTextLength()**

        Constructs a new length object which represents a variable size.
        """
        ...

    def rawValue(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextlength.html#rawValue

        **qreal QTextLength::rawValue() const**

        Returns the constraint value that is specific for the type of the
        length. If the length is **QTextLength::PercentageLength**  then the raw
        value is in percent, in the range of 0 to 100. If the length is
        **QTextLength::FixedLength**  then that fixed amount is returned. For
        variable lengths, zero is returned.
        """
        ...

    def value(self, maximumLength: float) -> float:
        """
        https://doc.qt.io/qt-6/qtextlength.html#value

        **qreal QTextLength::value(qreal maximumLength ) const**

        Returns the effective length, constrained by the type of the length
        object and the specified **maximumLength**.

        **See also** **type** ().
        """
        ...

    def type(self) -> "QTextLength.Type":
        """
        https://doc.qt.io/qt-6/qtextlength.html#type

        **QTextLength::Type QTextLength::type() const**

        Returns the type of this length object.

        **See also** **QTextLength::Type** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtOpenGL import *
import enum


class QOpenGLDebugMessage(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopengldebugmessage.html

    **Detailed Description**

    Debug messages are usually created by the OpenGL server and then read by
    OpenGL clients (either from the OpenGL internal debug log, or logged in
    real-time). A debug message has a textual representation, a vendor-specific
    numeric id, a source, a type and a severity.

    It's also possible for applications or third-party libraries and toolkits to
    create and insert messages in the debug log. In order to do so, you can use
    the **createApplicationMessage** () or the **createThirdPartyMessage** ()
    static functions.

    **See also** **QOpenGLDebugLogger** .
    """

    class Severity(enum.Flag):
        InvalidSeverity: QOpenGLDebugMessage = ...
        HighSeverity: QOpenGLDebugMessage = ...
        MediumSeverity: QOpenGLDebugMessage = ...
        LowSeverity: QOpenGLDebugMessage = ...
        NotificationSeverity: QOpenGLDebugMessage = ...
        AnySeverity: QOpenGLDebugMessage = ...

    class Type(enum.Flag):
        InvalidType: QOpenGLDebugMessage = ...
        ErrorType: QOpenGLDebugMessage = ...
        DeprecatedBehaviorType: QOpenGLDebugMessage = ...
        UndefinedBehaviorType: QOpenGLDebugMessage = ...
        PortabilityType: QOpenGLDebugMessage = ...
        PerformanceType: QOpenGLDebugMessage = ...
        OtherType: QOpenGLDebugMessage = ...
        MarkerType: QOpenGLDebugMessage = ...
        GroupPushType: QOpenGLDebugMessage = ...
        GroupPopType: QOpenGLDebugMessage = ...
        AnyType: QOpenGLDebugMessage = ...

    class Source(enum.Flag):
        InvalidSource: QOpenGLDebugMessage = ...
        APISource: QOpenGLDebugMessage = ...
        WindowSystemSource: QOpenGLDebugMessage = ...
        ShaderCompilerSource: QOpenGLDebugMessage = ...
        ThirdPartySource: QOpenGLDebugMessage = ...
        ApplicationSource: QOpenGLDebugMessage = ...
        OtherSource: QOpenGLDebugMessage = ...
        AnySource: QOpenGLDebugMessage = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#QOpenGLDebugMessage

        **QOpenGLDebugMessage::QOpenGLDebugMessage()**

        Constructs a debug message with an empty message string, id set to 0,
        source set to **InvalidSource** , type set to **InvalidType** , and
        severity set to **InvalidSeverity** .

        **Note:** This constructor should not be used to create a debug message;
        instead, use the **createApplicationMessage** () or the
        **createThirdPartyMessage** () static functions.

        **See also** **createApplicationMessage** () and
        **createThirdPartyMessage** ().
        """
        ...

    @typing.overload
    def __init__(self, debugMessage: "QOpenGLDebugMessage") -> None:
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#QOpenGLDebugMessage-1

        **QOpenGLDebugMessage::QOpenGLDebugMessage(const QOpenGLDebugMessage &
        debugMessage )**

        Constructs a debug message as a copy of **debugMessage**.

        **See also** **operator=** ().
        """
        ...

    @staticmethod
    def createThirdPartyMessage(
        text: str,
        id: int = ...,
        severity: "QOpenGLDebugMessage.Severity" = ...,
        type: "QOpenGLDebugMessage.Type" = ...,
    ) -> "QOpenGLDebugMessage":
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#createThirdPartyMessage

        **[static] QOpenGLDebugMessage
        QOpenGLDebugMessage::createThirdPartyMessage(const QString & text ,
        GLuint id = 0, QOpenGLDebugMessage::Severity severity =
        NotificationSeverity, QOpenGLDebugMessage::Type type = OtherType)**

        Constructs and returns a debug message with **text** as its text, **id**
        as id, **severity** as severity, and **type** as type. The message
        source will be set to **ThirdPartySource** .

        **See also** **QOpenGLDebugLogger::logMessage** () and
        **createApplicationMessage** ().
        """
        ...

    @staticmethod
    def createApplicationMessage(
        text: str,
        id: int = ...,
        severity: "QOpenGLDebugMessage.Severity" = ...,
        type: "QOpenGLDebugMessage.Type" = ...,
    ) -> "QOpenGLDebugMessage":
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#createApplicationMessage

        **[static] QOpenGLDebugMessage
        QOpenGLDebugMessage::createApplicationMessage(const QString & text ,
        GLuint id = 0, QOpenGLDebugMessage::Severity severity =
        NotificationSeverity, QOpenGLDebugMessage::Type type = OtherType)**

        Constructs and returns a debug message with **text** as its text, **id**
        as id, **severity** as severity, and **type** as type. The message
        source will be set to **ApplicationSource** .

        **See also** **QOpenGLDebugLogger::logMessage** () and
        **createThirdPartyMessage** ().
        """
        ...

    def message(self) -> str:
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#message

        **QString QOpenGLDebugMessage::message() const**

        Returns the textual message contained by this debug message.
        """
        ...

    def id(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#id

        **GLuint QOpenGLDebugMessage::id() const**

        Returns the id of the debug message. Ids are generally vendor-specific.
        """
        ...

    def severity(self) -> "QOpenGLDebugMessage.Severity":
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#severity

        **QOpenGLDebugMessage::Severity QOpenGLDebugMessage::severity() const**

        Returns the severity of the debug message.
        """
        ...

    def type(self) -> "QOpenGLDebugMessage.Type":
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#type

        **QOpenGLDebugMessage::Type QOpenGLDebugMessage::type() const**

        Returns the type of the debug message.
        """
        ...

    def source(self) -> "QOpenGLDebugMessage.Source":
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#source

        **QOpenGLDebugMessage::Source QOpenGLDebugMessage::source() const**

        Returns the source of the debug message.
        """
        ...

    def swap(self, debugMessage: "QOpenGLDebugMessage") -> None:
        """
        https://doc.qt.io/qt-6/qopengldebugmessage.html#swap

        **void QOpenGLDebugMessage::swap(QOpenGLDebugMessage & debugMessage )**

        Swaps the message **debugMessage** with this message. This operation is
        very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6 import QtSvg
from PyQt6 import QtGui
from PyQt6 import QtCore


class QGraphicsSvgItem(QtWidgets.QGraphicsObject):
    """
    https://doc.qt.io/qt-6/qgraphicssvgitem.html

    **Detailed Description**

    QGraphicsSvgItem provides a way of rendering SVG files onto
    **QGraphicsView** . QGraphicsSvgItem can be created by passing the SVG file
    to be rendered to its constructor or by explicit setting a shared
    **QSvgRenderer**  on it.

    Note that setting **QSvgRenderer**  on a QGraphicsSvgItem doesn't make the
    item take ownership of the renderer, therefore if using
    **setSharedRenderer** () method one has to make sure that the lifetime of
    the **QSvgRenderer**  object will be at least as long as that of the
    QGraphicsSvgItem.

    QGraphicsSvgItem provides a way of rendering only parts of the SVG files via
    the **setElementId** . If **setElementId** () method is called, only the SVG
    element (and its children) with the passed id will be renderer. This
    provides a convenient way of selectively rendering large SVG files that
    contain a number of discrete elements. For example the following code
    renders only jokers from a SVG file containing a whole card deck:

    **QSvgRenderer**  *renderer = new **QSvgRenderer**
    (QLatin1String("SvgCardDeck.svg"));
        **QGraphicsSvgItem**  *black = new
    **QGraphicsSvgItem** ();
        **QGraphicsSvgItem**  *red   = new
    **QGraphicsSvgItem** ();

        black->setSharedRenderer(renderer);
    black->setElementId(QLatin1String("black_joker"));
    red->setSharedRenderer(renderer);
    red->setElementId(QLatin1String("red_joker"));

    Size of the item can be set via direct manipulation of the items
    transformation matrix.

    By default the SVG rendering is cached using
    **QGraphicsItem::DeviceCoordinateCache**  mode to speedup the display of
    items. Caching can be disabled by passing **QGraphicsItem::NoCache**  to the
    **QGraphicsItem::setCacheMode** () method.

    **See also** **QSvgWidget** , **Qt SVG C++ Classes** , **QGraphicsItem** ,
    and **QGraphicsView** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtWidgets.QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#QGraphicsSvgItem

        **QGraphicsSvgItem::QGraphicsSvgItem(QGraphicsItem * parent = nullptr)**

        Constructs a new SVG item with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, fileName: str, parent: typing.Optional[QtWidgets.QGraphicsItem] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#QGraphicsSvgItem-1

        **QGraphicsSvgItem::QGraphicsSvgItem(const QString & fileName ,
        QGraphicsItem * parent = nullptr)**

        Constructs a new item with the given **parent** and loads the contents
        of the SVG file with the specified **fileName**.
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#type

        **[override virtual] int QGraphicsSvgItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: QtWidgets.QStyleOptionGraphicsItem,
        widget: typing.Optional[QtWidgets.QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#paint

        **[override virtual] void QGraphicsSvgItem::paint(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget = nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#boundingRect

        **[override virtual] QRectF QGraphicsSvgItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .

        Returns the bounding rectangle of this item.
        """
        ...

    def maximumCacheSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#maximumCacheSize

        **QSize QGraphicsSvgItem::maximumCacheSize() const**

        Returns the current maximum size of the device coordinate cache for this
        item. If the item is cached using
        **QGraphicsItem::DeviceCoordinateCache**  mode, caching is bypassed if
        the extension of the item in device coordinates is larger than the
        maximum size.

        The default maximum cache size is 1024x768. **QPixmapCache::cacheLimit**
        () gives the cumulative bounds of the whole cache, whereas
        maximumCacheSize() refers to a maximum cache size for this particular
        item.

        **Note:** Getter function for property maximumCacheSize.

        **See also** **setMaximumCacheSize** () and **QGraphicsItem::cacheMode**
        ().
        """
        ...

    def setMaximumCacheSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#setMaximumCacheSize

        **void QGraphicsSvgItem::setMaximumCacheSize(const QSize & size )**

        Sets the maximum device coordinate cache size of the item to **size**.
        If the item is cached using **QGraphicsItem::DeviceCoordinateCache**
        mode, caching is bypassed if the extension of the item in device
        coordinates is larger than **size**.

        The cache corresponds to the **QPixmap**  which is used to cache the
        results of the rendering. Use **QPixmapCache::setCacheLimit** () to set
        limitations on the whole cache and use setMaximumCacheSize() when
        setting cache size for individual items.

        **Note:** Setter function for property **maximumCacheSize** .

        **See also** **maximumCacheSize** () and **QGraphicsItem::cacheMode**
        ().
        """
        ...

    def elementId(self) -> str:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#elementId

        **QString QGraphicsSvgItem::elementId() const**

        Returns the XML ID the element that is currently being rendered. Returns
        an empty string if the whole file is being rendered.

        **Note:** Getter function for property elementId.

        **See also** **setElementId** ().
        """
        ...

    def setElementId(self, id: str) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#setElementId

        **void QGraphicsSvgItem::setElementId(const QString & id )**

        Sets the XML ID of the element to **id**.

        **Note:** Setter function for property **elementId** .

        **See also** **elementId** ().
        """
        ...

    def renderer(self) -> QtSvg.QSvgRenderer:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#renderer

        **QSvgRenderer *QGraphicsSvgItem::renderer() const**

        Returns the currently use **QSvgRenderer** .
        """
        ...

    def setSharedRenderer(self, renderer: QtSvg.QSvgRenderer) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssvgitem.html#setSharedRenderer

        **void QGraphicsSvgItem::setSharedRenderer(QSvgRenderer * renderer )**

        Sets **renderer** to be a shared **QSvgRenderer**  on the item. By using
        this method one can share the same **QSvgRenderer**  on a number of
        items. This means that the SVG file will be parsed only once.
        **QSvgRenderer**  passed to this method has to exist for as long as this
        item is used.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QJsonParseError(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsonparseerror.html

    **Detailed Description**

    **See also** **JSON Support in Qt**  and **JSON Save Game Example** .
    """

    class ParseError(enum.Enum):
        NoError: QJsonParseError = ...
        UnterminatedObject: QJsonParseError = ...
        MissingNameSeparator: QJsonParseError = ...
        UnterminatedArray: QJsonParseError = ...
        MissingValueSeparator: QJsonParseError = ...
        IllegalValue: QJsonParseError = ...
        TerminationByNumber: QJsonParseError = ...
        IllegalNumber: QJsonParseError = ...
        IllegalEscapeSequence: QJsonParseError = ...
        IllegalUTF8String: QJsonParseError = ...
        UnterminatedString: QJsonParseError = ...
        MissingObject: QJsonParseError = ...
        DeepNesting: QJsonParseError = ...
        DocumentTooLarge: QJsonParseError = ...
        GarbageAtEnd: QJsonParseError = ...

    error = ...
    offset: int = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QJsonParseError") -> None:
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsonparseerror.html#errorString

        **QString QJsonParseError::errorString() const**

        Returns the human-readable message appropriate to the reported JSON
        parsing error.

        **See also** **error** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QUuid(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/quuid.html

    **Detailed Description**

    Using **U** niversally **U** nique **ID** entifiers (UUID) is a standard way
    to uniquely identify entities in a distributed computing environment. A UUID
    is a 16-byte (128-bit) number generated by some algorithm that is meant to
    guarantee that the UUID will be unique in the distributed computing
    environment where it is used. The acronym GUID is often used instead, **G**
    lobally **U** nique **ID** entifiers, but it refers to the same thing.

    Actually, the GUID is one **variant** of UUID. Multiple variants are in use.
    Each UUID contains a bit field that specifies which type (variant) of UUID
    it is. Call **variant** () to discover which type of UUID an instance of
    QUuid contains. It extracts the three most significant bits of byte 8 of the
    16 bytes. In QUuid, byte 8 is `QUuid::data4[0]`. If you create instances of
    QUuid using the constructor that accepts all the numeric values as
    parameters, use the following table to set the three most significant bits
    of parameter `b1`, which becomes `QUuid::data4[0]` and contains the variant
    field in its three most significant bits. In the table, 'x' means **don't
    care**.

    msb0msb1msb2Variant
    0xxNCS (Network Computing System)
    10xDCE
    (Distributed Computing Environment)
    110Microsoft (GUID)
    111Reserved for
    future expansion

    If **variant** () returns **QUuid::DCE** , the UUID also contains a
    **version** field in the four most significant bits of `QUuid::data3`, and
    you can call **version** () to discover which version your QUuid contains.
    If you create instances of QUuid using the constructor that accepts all the
    numeric values as parameters, use the following table to set the four most
    significant bits of parameter `w2`, which becomes `QUuid::data3` and
    contains the version field in its four most significant bits.

    msb0msb1msb2msb3Version
    0001Time
    0010Embedded POSIX
    0011Md5(Name)
    0100Random
    0101Sha1

    The field layouts for the DCE versions listed in the table above are
    specified in the **Network Working Group UUID Specification** .

    Most platforms provide a tool for generating new UUIDs, e.g. `uuidgen` and
    `guidgen`. You can also use **createUuid** (). UUIDs generated by
    **createUuid** () are of the random type. Their **QUuid::Version**  bits are
    set to **QUuid::Random** , and their **QUuid::Variant**  bits are set to
    **QUuid::DCE** . The rest of the UUID is composed of random numbers.
    Theoretically, this means there is a small chance that a UUID generated by
    **createUuid** () will not be unique. But it is **a **very** small chance**
    .

    UUIDs can be constructed from numeric values or from strings, or using the
    static **createUuid** () function. They can be converted to a string with
    **toString** (). UUIDs have a **variant** () and a **version** (), and null
    UUIDs return true from **isNull** ().
    """

    class StringFormat(enum.Enum):
        WithBraces: QUuid = ...
        WithoutBraces: QUuid = ...
        Id128: QUuid = ...

    class Version(enum.Enum):
        VerUnknown: QUuid = ...
        Time: QUuid = ...
        EmbeddedPOSIX: QUuid = ...
        Md5: QUuid = ...
        Name: QUuid = ...
        Random: QUuid = ...
        Sha1: QUuid = ...

    class Variant(enum.Enum):
        VarUnknown: QUuid = ...
        NCS: QUuid = ...
        DCE: QUuid = ...
        Microsoft: QUuid = ...
        Reserved: QUuid = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/quuid.html#QUuid

        **QUuid::QUuid(const QByteArray & text )**

        Creates a QUuid object from the **QByteArray**  **text** , which must be
        formatted as five hex fields separated by '-', e.g., "{xxxxxxxx-xxxx-
        xxxx-xxxx-xxxxxxxxxxxx}" where each 'x' is a hex digit. The curly braces
        shown here are optional, but it is normal to include them. If the
        conversion fails, a null UUID is created. See **toByteArray** () for an
        explanation of how the five hex fields map to the public data members in
        QUuid.

        **See also** **toByteArray** () and **QUuid** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        l: int,
        w1: int,
        w2: int,
        b1: int,
        b2: int,
        b3: int,
        b4: int,
        b5: int,
        b6: int,
        b7: int,
        b8: int,
    ) -> None:
        """
        https://doc.qt.io/qt-6/quuid.html#QUuid-1

        **QUuid::QUuid()**

        Creates the null UUID. **toString** () will output the null UUID as
        "{00000000-0000-0000-0000-000000000000}".
        """
        ...

    @typing.overload
    def __init__(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/quuid.html#QUuid-2

        **QUuid::QUuid(uint l , ushort w1 , ushort w2 , uchar b1 , uchar b2 ,
        uchar b3 , uchar b4 , uchar b5 , uchar b6 , uchar b7 , uchar b8 )**

        Creates a UUID with the value specified by the parameters, **l** ,
        **w1** , **w2** , **b1** , **b2** , **b3** , **b4** , **b5** , **b6** ,
        **b7** , **b8**.

        Example:

        // {67C8770B-44F1-410A-AB9A-F9B5446F13EE}
            QUuid
        IID_MyInterface(0x67c8770b, 0x44f1, 0x410a, 0xab, 0x9a, 0xf9, 0xb5,
        0x44, 0x6f, 0x13, 0xee);
        """
        ...

    @typing.overload
    def __init__(self, a0: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/quuid.html#QUuid-3

        **QUuid::QUuid(const QString & text )**

        Creates a QUuid object from the string **text** , which must be
        formatted as five hex fields separated by '-', e.g., "{xxxxxxxx-xxxx-
        xxxx-xxxx-xxxxxxxxxxxx}" where each 'x' is a hex digit. The curly braces
        shown here are optional, but it is normal to include them. If the
        conversion fails, a null UUID is created. See **toString** () for an
        explanation of how the five hex fields map to the public data members in
        QUuid.

        **See also** **toString** () and **QUuid** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QUuid") -> None:
        """
        https://doc.qt.io/qt-6/quuid.html#QUuid-4

        **QUuid::QUuid(const GUID & guid )**

        Casts a Windows **guid** to a Qt QUuid.

        **Warning:** This function is only for Windows platforms.
        """
        ...

    @staticmethod
    def fromRfc4122(a0: QByteArray) -> "QUuid":
        """
        https://doc.qt.io/qt-6/quuid.html#fromRfc4122

        **[static] QUuid QUuid::fromRfc4122(const QByteArray & bytes )**

        Creates a **QUuid**  object from the binary representation of the UUID,
        as specified by RFC 4122 section 4.1.2. See **toRfc4122** () for a
        further explanation of the order of **bytes** required.

        The byte array accepted is NOT a human readable format.

        If the conversion fails, a null UUID is created.

        **See also** **toRfc4122** () and **QUuid** ().
        """
        ...

    def toRfc4122(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/quuid.html#toRfc4122

        **QByteArray QUuid::toRfc4122() const**

        Returns the binary representation of this **QUuid** . The byte array is
        in big endian format, and formatted according to RFC 4122, section 4.1.2
        - "Layout and byte order".

        The order is as follows:

        Field #Source
        1data1
        2data2
        3data3
        4data4[0] .. data4[7]
        """
        ...

    def toByteArray(self, mode: "QUuid.StringFormat" = ...) -> QByteArray:
        """
        https://doc.qt.io/qt-6/quuid.html#toByteArray

        **[since 5.11] QByteArray QUuid::toByteArray(QUuid::StringFormat mode =
        WithBraces) const**

        Returns the string representation of this **QUuid** , with the
        formattiong controlled by the **mode** parameter. From left to right,
        the five hex fields are obtained from the four public data members in
        **QUuid**  as follows:

        Field #Source
        1data1
        2data2
        3data3
        4data4[0] .. data4[1]
        5data4[2] .. data4[7]

        This function was introduced in Qt 5.11.
        """
        ...

    def version(self) -> "QUuid.Version":
        """
        https://doc.qt.io/qt-6/quuid.html#version

        **QUuid::Version QUuid::version() const**

        Returns the **version field**  of the UUID, if the UUID's **variant
        field**  is **QUuid::DCE** . Otherwise it returns **QUuid::VerUnknown**
        .

        **See also** **variant** ().
        """
        ...

    def variant(self) -> "QUuid.Variant":
        """
        https://doc.qt.io/qt-6/quuid.html#variant

        **QUuid::Variant QUuid::variant() const**

        Returns the value in the **variant field**  of the UUID. If the return
        value is **QUuid::DCE** , call **version** () to see which layout it
        uses. The null UUID is considered to be of an unknown variant.

        **See also** **version** ().
        """
        ...

    @typing.overload
    @staticmethod
    def createUuidV5(ns: "QUuid", baseData: QByteArray) -> "QUuid":
        """
        https://doc.qt.io/qt-6/quuid.html#createUuidV5

        **[static, since 5.0] QUuid QUuid::createUuidV5(const QUuid & ns , const
        QByteArray & baseData )**

        This function returns a new UUID with variant **QUuid::DCE**  and
        version **QUuid::Sha1** . **ns** is the namespace and **baseData** is
        the basic data as described by RFC 4122.

        This function was introduced in Qt 5.0.

        **See also** **variant** (), **version** (), and **createUuidV3** ().
        """
        ...

    @typing.overload
    @staticmethod
    def createUuidV5(ns: "QUuid", baseData: str) -> "QUuid":
        """
        https://doc.qt.io/qt-6/quuid.html#createUuidV5-1

        **[static, since 5.0] QUuid QUuid::createUuidV5(const QUuid & ns , const
        QString & baseData )**

        This function returns a new UUID with variant **QUuid::DCE**  and
        version **QUuid::Sha1** . **ns** is the namespace and **baseData** is
        the basic data as described by RFC 4122.

        This function was introduced in Qt 5.0.

        **See also** **variant** (), **version** (), and **createUuidV3** ().
        """
        ...

    @typing.overload
    @staticmethod
    def createUuidV3(ns: "QUuid", baseData: QByteArray) -> "QUuid":
        """
        https://doc.qt.io/qt-6/quuid.html#createUuidV3

        **[static, since 5.0] QUuid QUuid::createUuidV3(const QUuid & ns , const
        QByteArray & baseData )**

        This function returns a new UUID with variant **QUuid::DCE**  and
        version **QUuid::Md5** . **ns** is the namespace and **baseData** is the
        basic data as described by RFC 4122.

        This function was introduced in Qt 5.0.

        **See also** **variant** (), **version** (), and **createUuidV5** ().
        """
        ...

    @typing.overload
    @staticmethod
    def createUuidV3(ns: "QUuid", baseData: str) -> "QUuid":
        """
        https://doc.qt.io/qt-6/quuid.html#createUuidV3-1

        **[static, since 5.0] QUuid QUuid::createUuidV3(const QUuid & ns , const
        QString & baseData )**

        This function returns a new UUID with variant **QUuid::DCE**  and
        version **QUuid::Md5** . **ns** is the namespace and **baseData** is the
        basic data as described by RFC 4122.

        This function was introduced in Qt 5.0.

        **See also** **variant** (), **version** (), and **createUuidV5** ().
        """
        ...

    @staticmethod
    def createUuid() -> "QUuid":
        """
        https://doc.qt.io/qt-6/quuid.html#createUuid

        **[static] QUuid QUuid::createUuid()**

        On any platform other than Windows, this function returns a new UUID
        with variant **QUuid::DCE**  and version **QUuid::Random** . On Windows,
        a GUID is generated using the Windows API and will be of the type that
        the API decides to create.

        **See also** **variant** () and **version** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/quuid.html#isNull

        **bool QUuid::isNull() const**

        Returns `true` if this is the null UUID
        {00000000-0000-0000-0000-000000000000}; otherwise returns `false`.
        """
        ...

    def toString(self, mode: "QUuid.StringFormat" = ...) -> str:
        """
        https://doc.qt.io/qt-6/quuid.html#toString

        **[since 5.11] QString QUuid::toString(QUuid::StringFormat mode =
        WithBraces) const**

        Returns the string representation of this **QUuid** , with the
        formattiong controlled by the **mode** parameter. From left to right,
        the five hex fields are obtained from the four public data members in
        **QUuid**  as follows:

        Field #Source
        1data1
        2data2
        3data3
        4data4[0] .. data4[1]
        5data4[2] .. data4[7]

        This function was introduced in Qt 5.11.
        """
        ...

    def __repr__(self) -> str:
        ...

    def __hash__(self) -> int:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QCompressedHelpInfo import QCompressedHelpInfo as QCompressedHelpInfo
from ._QHelpContentItem import QHelpContentItem as QHelpContentItem
from ._QHelpContentModel import QHelpContentModel as QHelpContentModel
from ._QHelpContentWidget import QHelpContentWidget as QHelpContentWidget
from ._QHelpEngineCore import QHelpEngineCore as QHelpEngineCore
from ._QHelpEngine import QHelpEngine as QHelpEngine
from ._QHelpFilterData import QHelpFilterData as QHelpFilterData
from ._QHelpFilterEngine import QHelpFilterEngine as QHelpFilterEngine
from ._QHelpFilterSettingsWidget import (
    QHelpFilterSettingsWidget as QHelpFilterSettingsWidget,
)
from ._QHelpIndexModel import QHelpIndexModel as QHelpIndexModel
from ._QHelpIndexWidget import QHelpIndexWidget as QHelpIndexWidget
from ._QHelpLink import QHelpLink as QHelpLink
from ._QHelpSearchQuery import QHelpSearchQuery as QHelpSearchQuery
from ._QHelpSearchEngine import QHelpSearchEngine as QHelpSearchEngine
from ._QHelpSearchResult import QHelpSearchResult as QHelpSearchResult
from ._QHelpSearchQueryWidget import QHelpSearchQueryWidget as QHelpSearchQueryWidget
from ._QHelpSearchResultWidget import QHelpSearchResultWidget as QHelpSearchResultWidget



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QTcpSocket(QAbstractSocket):
    """
    https://doc.qt.io/qt-6/qtcpsocket.html

    **Detailed Description**

    TCP (Transmission Control Protocol) is a reliable, stream-oriented,
    connection-oriented transport protocol. It is especially well suited for
    continuous transmission of data.

    QTcpSocket is a convenience subclass of **QAbstractSocket**  that allows you
    to establish a TCP connection and transfer streams of data. See the
    **QAbstractSocket**  documentation for details.

    **Note:** TCP sockets cannot be opened in QIODevice::Unbuffered mode.

    **See also** **QTcpServer** , **QUdpSocket** , **QNetworkAccessManager** ,
    **Fortune Server Example** , **Fortune Client Example** , **Threaded Fortune
    Server Example** , **Blocking Fortune Client Example** , **Loopback
    Example** , and **Torrent Example** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtcpsocket.html#QTcpSocket

        **QTcpSocket::QTcpSocket(QObject * parent = nullptr)**

        Creates a QTcpSocket object in state `UnconnectedState`.

        **parent** is passed on to the **QObject**  constructor.

        **See also** **socketType** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QSslPreSharedKeyAuthenticator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html

    **Detailed Description**

    The QSslPreSharedKeyAuthenticator class is used by an SSL socket to provide
    the required authentication data in a pre shared key (PSK) ciphersuite.

    In a PSK handshake, the client must derive a key, which must match the key
    set on the server. The exact algorithm of deriving the key depends on the
    application; however, for this purpose, the server may send an **identity
    hint** to the client. This hint, combined with other information (for
    instance a passphrase), is then used by the client to construct the shared
    key.

    The QSslPreSharedKeyAuthenticator provides means to client applications for
    completing the PSK handshake. The client application needs to connect a slot
    to the **QSslSocket::preSharedKeyAuthenticationRequired** () signal:

    connect(socket, &**QSslSocket** ::preSharedKeyAuthenticationRequired,
    this, &AuthManager::handlePreSharedKeyAuthentication);

    The signal carries a QSslPreSharedKeyAuthenticator object containing the
    identity hint the server sent to the client, and which must be filled with
    the corresponding client identity and the derived key:

    void AuthManager::handlePreSharedKeyAuthentication(**QSslPreSharedKeyAuthent
    icator**  *authenticator)
            {
    authenticator->setIdentity("My Qt App");

                const
    **QByteArray**  key = deriveKey(authenticator->identityHint(), passphrase);
    authenticator->setPreSharedKey(key);
            }

    **Note:** PSK ciphersuites are supported only when using OpenSSL 1.0.1 (or
    greater) as the SSL backend.

    **Note:** PSK is currently only supported in OpenSSL.

    **See also** **QSslSocket** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#QSslPreSharedK
        eyAuthenticator

        **QSslPreSharedKeyAuthenticator::QSslPreSharedKeyAuthenticator()**

        Constructs a default QSslPreSharedKeyAuthenticator object.

        The identity hint, the identity and the key will be initialized to empty
        byte arrays; the maximum length for both the identity and the key will
        be initialized to 0.
        """
        ...

    @typing.overload
    def __init__(self, authenticator: "QSslPreSharedKeyAuthenticator") -> None:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#QSslPreSharedK
        eyAuthenticator-1

        **QSslPreSharedKeyAuthenticator::QSslPreSharedKeyAuthenticator(const
        QSslPreSharedKeyAuthenticator & authenticator )**

        Constructs a QSslPreSharedKeyAuthenticator object as a copy of
        **authenticator**.

        **See also** **operator=** ().
        """
        ...

    def maximumPreSharedKeyLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#maximumPreShar
        edKeyLength

        **int QSslPreSharedKeyAuthenticator::maximumPreSharedKeyLength() const**

        Returns the maximum length, in bytes, of the pre shared key.

        **Note:** it is possible to set a key whose length is greater than the
        maximumPreSharedKeyLength(); in this case, only the first
        maximumPreSharedKeyLength() bytes will be actually sent to the server.

        **See also** **setPreSharedKey** ().
        """
        ...

    def preSharedKey(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#preSharedKey

        **QByteArray QSslPreSharedKeyAuthenticator::preSharedKey() const**

        Returns the pre shared key.

        **See also** **setPreSharedKey** ().
        """
        ...

    def setPreSharedKey(self, preSharedKey: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#setPreSharedKe
        y

        **void QSslPreSharedKeyAuthenticator::setPreSharedKey(const QByteArray &
        preSharedKey )**

        Sets the pre shared key to **preSharedKey**.

        **Note:** it is possible to set a key whose length is greater than the
        **maximumPreSharedKeyLength** (); in this case, only the first
        **maximumPreSharedKeyLength** () bytes will be actually sent to the
        server.

        **See also** **preSharedKey** (), **maximumPreSharedKeyLength** (), and
        **QByteArray::fromHex** ().
        """
        ...

    def maximumIdentityLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#maximumIdentit
        yLength

        **int QSslPreSharedKeyAuthenticator::maximumIdentityLength() const**

        Returns the maximum length, in bytes, of the PSK client identity.

        **Note:** it is possible to set an identity whose length is greater than
        maximumIdentityLength(); in this case, only the first
        maximumIdentityLength() bytes will be actually sent to the server.

        **See also** **setIdentity** ().
        """
        ...

    def identity(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#identity

        **QByteArray QSslPreSharedKeyAuthenticator::identity() const**

        Returns the PSK client identity.

        **See also** **setIdentity** ().
        """
        ...

    def setIdentity(self, identity: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#setIdentity

        **void QSslPreSharedKeyAuthenticator::setIdentity(const QByteArray &
        identity )**

        Sets the PSK client identity (to be advised to the server) to
        **identity**.

        **Note:** it is possible to set an identity whose length is greater than
        **maximumIdentityLength** (); in this case, only the first
        **maximumIdentityLength** () bytes will be actually sent to the server.

        **See also** **identity** () and **maximumIdentityLength** ().
        """
        ...

    def identityHint(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#identityHint

        **QByteArray QSslPreSharedKeyAuthenticator::identityHint() const**

        Returns the PSK identity hint as provided by the server. The
        interpretation of this hint is left to the application.
        """
        ...

    def swap(self, authenticator: "QSslPreSharedKeyAuthenticator") -> None:
        """
        https://doc.qt.io/qt-6/qsslpresharedkeyauthenticator.html#swap

        **void QSslPreSharedKeyAuthenticator::swap(QSslPreSharedKeyAuthenticator
        & authenticator )**

        Swaps the **QSslPreSharedKeyAuthenticator**  object **authenticator**
        with this object. This operation is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QAudioBuffer(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qaudiobuffer.html

    **Detailed Description**

    QAudioBuffer is used by the **QAudioDecoder**  class to hand decoded audio
    data over to the application. An audio buffer contains data in a certain
    **QAudioFormat**  that can be queried using **format** (). It is also tagged
    with timing and duration information.

    To access the data stored inside the buffer, use the **data** () or
    **constData** () methods.

    Audio buffers are explicitly shared, in most cases, you should call
    **detach** () before modifying the data.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#QAudioBuffer

        **QAudioBuffer::QAudioBuffer()**

        Create a new, empty, invalid buffer.
        """
        ...

    @typing.overload
    def __init__(
        self, data: QtCore.QByteArray, format: "QAudioFormat", startTime: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#QAudioBuffer-1

        **QAudioBuffer::QAudioBuffer(const QAudioBuffer & other )**

        Creates a new audio buffer from **other**. Audio buffers are explicitly
        shared, you should call **detach** () on the buffer to make a copy that
        can then be modified.
        """
        ...

    @typing.overload
    def __init__(
        self, numFrames: int, format: "QAudioFormat", startTime: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#QAudioBuffer-2

        **QAudioBuffer::QAudioBuffer(const QByteArray & data , const
        QAudioFormat & format , qint64 startTime = -1)**

        Creates a new audio buffer from the supplied **data** , in the given
        **format**. The format will determine how the number and sizes of the
        samples are interpreted from the **data**.

        If the supplied **data** is not an integer multiple of the calculated
        frame size, the excess data will not be used.

        This audio buffer will copy the contents of **data**.

        **startTime** (in microseconds) indicates when this buffer starts in the
        stream. If this buffer is not part of a stream, set it to -1.
        """
        ...

    @typing.overload
    def __init__(self, other: "QAudioBuffer") -> None:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#QAudioBuffer-3

        **QAudioBuffer::QAudioBuffer(int numFrames , const QAudioFormat & format
        , qint64 startTime = -1)**

        Creates a new audio buffer with space for **numFrames** frames of the
        given **format**. The individual samples will be initialized to the
        default for the format.

        **startTime** (in microseconds) indicates when this buffer starts in the
        stream. If this buffer is not part of a stream, set it to -1.
        """
        ...

    def data(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#data

        **template <typename T> const T *QAudioBuffer::data() const**

        Returns a pointer to this buffer's data. You can only read it.

        You should use the **constData** () function rather than this to prevent
        accidental deep copying.

        There is also a templatized version of this data() function that allows
        you to retrieve a specific type of read-only pointer to the data. Note
        that there is no checking done on the format of the audio buffer - this
        is simply a convenience function.

        // With a 16bit sample const buffer:
            const **quint16**  *data =
        buffer->data<**quint16** >();
        """
        ...

    def constData(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#constData

        **template <typename T> const T *QAudioBuffer::constData() const**

        Returns a pointer to this buffer's data. You can only read it.

        This method is preferred over the const version of **data** () to
        prevent unnecessary copying.

        There is also a templatized version of this constData() function that
        allows you to retrieve a specific type of read-only pointer to the data.
        Note that there is no checking done on the format of the audio buffer -
        this is simply a convenience function.

        // With a 16bit sample buffer:
            const **quint16**  *data =
        buffer->constData<**quint16** >();
        """
        ...

    def detach(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#detach

        **void QAudioBuffer::detach()**

        Detaches this audio buffers from other copies that might share data with
        it.
        """
        ...

    def swap(self, other: "QAudioBuffer") -> None:
        ...

    def startTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#startTime

        **qint64 QAudioBuffer::startTime() const**

        Returns the time in a stream that this buffer starts at (in
        microseconds).

        If this buffer is not part of a stream, this will return -1.
        """
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#duration

        **qint64 QAudioBuffer::duration() const**

        Returns the duration of audio in this buffer, in microseconds.

        This depends on the **format** (), and the **frameCount** ().
        """
        ...

    def byteCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#byteCount

        **qsizetype QAudioBuffer::byteCount() const**

        Returns the size of this buffer, in bytes.
        """
        ...

    def sampleCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#sampleCount

        **qsizetype QAudioBuffer::sampleCount() const**

        Returns the number of samples in this buffer.

        If the format of this buffer has multiple channels, then this count
        includes all channels. This means that a stereo buffer with 1000 samples
        in total will have 500 left samples and 500 right samples (interleaved),
        and this function will return 1000.

        **See also** **frameCount** ().
        """
        ...

    def frameCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#frameCount

        **qsizetype QAudioBuffer::frameCount() const**

        Returns the number of complete audio frames in this buffer.

        An audio frame is an interleaved set of one sample per channel for the
        same instant in time.
        """
        ...

    def format(self) -> "QAudioFormat":
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#format

        **QAudioFormat QAudioBuffer::format() const**

        Returns the **format**  of this buffer.

        Several properties of this format influence how the **duration** () or
        **byteCount** () are calculated from the **frameCount** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaudiobuffer.html#isValid

        **bool QAudioBuffer::isValid() const**

        Returns true if this is a valid buffer. A valid buffer has more than
        zero frames in it and a valid format.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QOperatingSystemVersion(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qoperatingsystemversion.html

    **Detailed Description**

    Unlike other version functions in **QSysInfo** , QOperatingSystemVersion
    provides access to the full version number that **developers** typically use
    to vary behavior or determine whether to enable APIs or features based on
    the operating system version (as opposed to the kernel version number or
    marketing version).

    Presently, Android, Apple Platforms (iOS, macOS, tvOS, and watchOS), and
    Windows are supported.

    The **majorVersion()** , **minorVersion()** , and **microVersion()**
    functions return the parts of the operating system version number based on:

    PlatformsValue
    Androidresult of parsing
    **android.os.Build.VERSION.RELEASE**  using **QVersionNumber** , with a
    fallback to **android.os.Build.VERSION.SDK_INT**  to determine the major and
    minor version component if the former fails
    Apple
    Platforms**majorVersion** , **minorVersion** , and patchVersion from
    **NSProcessInfo.operatingSystemVersion**
    WindowsdwMajorVersion,
    dwMinorVersion, and dwBuildNumber from **RtlGetVersion**  \\- note that this
    function ALWAYS return the version number of the underlying operating
    system, as opposed to the shim underneath GetVersionEx that hides the real
    version number if the application is not manifested for that version of the
    OS

    Because QOperatingSystemVersion stores both a version number and an OS type,
    the OS type can be taken into account when performing comparisons. For
    example, on a macOS system running macOS Sierra (v10.12), the following
    expression will return `false` even though the major version number
    component of the object on the left hand side of the expression (10) is
    greater than that of the object on the right (9):

    **QOperatingSystemVersion** ::current() >= **QOperatingSystemVersion**
    (**QOperatingSystemVersion** ::IOS, 9)

    This allows expressions for multiple operating systems to be joined with a
    logical OR operator and still work as expected. For example:

    auto current = **QOperatingSystemVersion** ::current();
            if (current
    >= **QOperatingSystemVersion** ::OSXYosemite ||
                current >=
    **QOperatingSystemVersion** (**QOperatingSystemVersion** ::IOS, 8)) {
    // returns true on macOS >= 10.10 and iOS >= 8.0, but false on macOS < 10.10
    and iOS < 8.0
            }

    A more naive comparison algorithm might incorrectly return true on all
    versions of macOS, including Mac OS 9. This behavior is achieved by
    overloading the comparison operators to return `false` whenever the OS types
    of the QOperatingSystemVersion instances being compared do not match. Be
    aware that due to this it can be the case `x` >= y and `x` < y are BOTH
    `false` for the same instances of `x` and `y`.
    """

    class OSType(enum.Enum):
        Unknown: QOperatingSystemVersion = ...
        Windows: QOperatingSystemVersion = ...
        MacOS: QOperatingSystemVersion = ...
        IOS: QOperatingSystemVersion = ...
        TvOS: QOperatingSystemVersion = ...
        WatchOS: QOperatingSystemVersion = ...
        Android: QOperatingSystemVersion = ...

    Android10 = ...
    Android11 = ...
    AndroidJellyBean = ...
    AndroidJellyBean_MR1 = ...
    AndroidJellyBean_MR2 = ...
    AndroidKitKat = ...
    AndroidLollipop = ...
    AndroidLollipop_MR1 = ...
    AndroidMarshmallow = ...
    AndroidNougat = ...
    AndroidNougat_MR1 = ...
    AndroidOreo = ...
    AndroidOreo_MR1 = ...
    AndroidPie = ...
    MacOSBigSur = ...
    MacOSCatalina = ...
    MacOSHighSierra = ...
    MacOSMojave = ...
    MacOSSierra = ...
    OSXElCapitan = ...
    OSXMavericks = ...
    OSXYosemite = ...
    Windows10 = ...
    Windows7 = ...
    Windows8 = ...
    Windows8_1 = ...

    @typing.overload
    def __init__(
        self,
        osType: "QOperatingSystemVersion.OSType",
        vmajor: int,
        vminor: int = ...,
        vmicro: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#QOperatingSystemVers
        ion

        **QOperatingSystemVersion::QOperatingSystemVersion(QOperatingSystemVersi
        on::OSType osType , int vmajor , int vminor = -1, int vmicro = -1)**

        Constructs a QOperatingSystemVersion consisting of the OS type
        **osType** , and major, minor, and micro version numbers **vmajor** ,
        **vminor** and **vmicro** , respectively.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QOperatingSystemVersion") -> None:
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#QOperatingSystemVers
        ion

        **QOperatingSystemVersion::QOperatingSystemVersion(QOperatingSystemVersi
        on::OSType osType , int vmajor , int vminor = -1, int vmicro = -1)**

        Constructs a QOperatingSystemVersion consisting of the OS type
        **osType** , and major, minor, and micro version numbers **vmajor** ,
        **vminor** and **vmicro** , respectively.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#name

        **QString QOperatingSystemVersion::name() const**

        Returns a string representation of the OS type identified by the
        **QOperatingSystemVersion** .

        **See also** **type** ().
        """
        ...

    def type(self) -> "QOperatingSystemVersion.OSType":
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#type

        **QOperatingSystemVersion::OSType QOperatingSystemVersion::type()
        const**

        Returns the OS type identified by the **QOperatingSystemVersion** .

        **See also** **name** ().
        """
        ...

    def segmentCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#segmentCount

        **int QOperatingSystemVersion::segmentCount() const**

        Returns the number of integers stored in the version number.
        """
        ...

    def microVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#microVersion

        **int QOperatingSystemVersion::microVersion() const**

        Returns the micro version number, that is, the third segment of the
        operating system's version number.

        See the main class documentation for what the micro version number is on
        a given operating system.

        -1 indicates an unknown or absent version number component.

        **See also** **version** (), **majorVersion** (), and **minorVersion**
        ().
        """
        ...

    def minorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#minorVersion

        **int QOperatingSystemVersion::minorVersion() const**

        Returns the minor version number, that is, the second segment of the
        operating system's version number.

        See the main class documentation for what the minor version number is on
        a given operating system.

        -1 indicates an unknown or absent version number component.

        **See also** **version** (), **majorVersion** (), and **microVersion**
        ().
        """
        ...

    def majorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#majorVersion

        **int QOperatingSystemVersion::majorVersion() const**

        Returns the major version number, that is, the first segment of the
        operating system's version number.

        See the main class documentation for what the major version number is on
        a given operating system.

        -1 indicates an unknown or absent version number component.

        **See also** **version** (), **minorVersion** (), and **microVersion**
        ().
        """
        ...

    def version(self) -> "QVersionNumber":
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#version

        **[since 6.1] QVersionNumber QOperatingSystemVersion::version() const**

        Returns the operating system's version number.

        See the main class documentation for what the version number is on a
        given operating system.

        This function was introduced in Qt 6.1.

        **See also** **majorVersion** (), **minorVersion** (), and
        **microVersion** ().
        """
        ...

    @staticmethod
    def currentType() -> "QOperatingSystemVersion.OSType":
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#currentType

        **[static, since 5.10] QOperatingSystemVersion::OSType
        QOperatingSystemVersion::currentType()**

        Returns the current OS type without constructing a
        **QOperatingSystemVersion**  instance.

        This function was introduced in Qt 5.10.

        **See also** **current** ().
        """
        ...

    @staticmethod
    def current() -> "QOperatingSystemVersion":
        """
        https://doc.qt.io/qt-6/qoperatingsystemversion.html#current

        **[static] QOperatingSystemVersion QOperatingSystemVersion::current()**

        Returns a **QOperatingSystemVersion**  indicating the current OS and its
        version number.

        **See also** **currentType** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QSGSimpleRectNode(QSGGeometryNode):
    """
    https://doc.qt.io/qt-6/qsgsimplerectnode.html

    **Detailed Description**

    **Warning:** This utility class is only functional when running with the
    default or software backends of the Qt Quick scenegraph. As an alternative,
    prefer using **QSGRectangleNode**  via **QQuickWindow::createRectangleNode**
    (). However, this standalone class is still useful when used via subclassing
    and the application knows that no special scenegraph backends will be
    involved.
    """

    @typing.overload
    def __init__(
        self,
        rect: QtCore.QRectF,
        color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimplerectnode.html#QSGSimpleRectNode

        **QSGSimpleRectNode::QSGSimpleRectNode(const QRectF & rect , const
        QColor & color )**

        Constructs a QSGSimpleRectNode instance which is spanning **rect** with
        the color **color**.
        """
        ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimplerectnode.html#QSGSimpleRectNode-1

        **QSGSimpleRectNode::QSGSimpleRectNode()**

        Constructs a QSGSimpleRectNode instance with an empty rectangle and
        white color.
        """
        ...

    def color(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qsgsimplerectnode.html#color

        **QColor QSGSimpleRectNode::color() const**

        Returns the color of this rectangle.

        **See also** **setColor** ().
        """
        ...

    def setColor(
        self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimplerectnode.html#setColor

        **void QSGSimpleRectNode::setColor(const QColor & color )**

        Sets the color of this rectangle to **color**. The default color will be
        white.

        **See also** **color** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgsimplerectnode.html#rect

        **QRectF QSGSimpleRectNode::rect() const**

        Returns the rectangle that this rect node covers.

        **See also** **setRect** ().
        """
        ...

    @typing.overload
    def setRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimplerectnode.html#setRect

        **void QSGSimpleRectNode::setRect(const QRectF & rect )**

        Sets the rectangle of this rect node to **rect**.

        **See also** **rect** ().
        """
        ...

    @typing.overload
    def setRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimplerectnode.html#setRect-1

        **void QSGSimpleRectNode::setRect(qreal x , qreal y , qreal w , qreal h
        )**

        This is an overloaded function.

        Sets the rectangle of this rect node to begin at ( **x** , **y** ) and
        have width **w** and height **h**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomText(QDomCharacterData):
    """
    https://doc.qt.io/qt-6/qdomtext.html

    **Detailed Description**

    You can split the text in a QDomText object over two QDomText objects with
    **splitText** ().

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomtext.html#QDomText

        **QDomText::QDomText()**

        Constructs an empty QDomText object.

        To construct a QDomText with content, use
        **QDomDocument::createTextNode** ().
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomText") -> None:
        """
        https://doc.qt.io/qt-6/qdomtext.html#QDomText-1

        **QDomText::QDomText(const QDomText & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomtext.html#nodeType

        **QDomNode::NodeType QDomText::nodeType() const**

        Returns `TextNode`.
        """
        ...

    def splitText(self, offset: int) -> "QDomText":
        """
        https://doc.qt.io/qt-6/qdomtext.html#splitText

        **QDomText QDomText::splitText(int offset )**

        Splits this DOM text object into two **QDomText**  objects. This object
        keeps its first **offset** characters and the second (newly created)
        object is inserted into the document tree after this object with the
        remaining characters.

        The function returns the newly created object.

        **See also** **QDomNode::normalize** ().
        """
        ...
